<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'activer_plugin' => 'Plugin activeren',
'affichage' => 'Display',
'aide_non_disponible' => 'Dit deel van de online handleiding is nog niet beschikbaar in het Nederlands.',
'auteur' => 'Auteur&nbsp;:',
'avis_acces_interdit' => 'Toegang verboden',
'avis_article_modifie' => 'Opgelet, @nom_auteur_modif@ heeft @date_diff@  minuten geleden aan dit artikel gewerkt.',
'avis_aucun_resultat' => 'Geen resultaat.',
'avis_chemin_invalide_1' => 'De toegang die je hebt gekozen',
'avis_chemin_invalide_2' => 'lijkt niet geldig. Gelieve terug te keren naar de vorige pagina en de ingevulde gegevens na te kijken.',
'avis_connexion_echec_1' => 'De verbinding met de database is mislukt.',
'avis_connexion_echec_2' => 'Keer terug naar de vorige pagina en kijk de gegevens na die je hebt ingevuld.',
'avis_connexion_echec_3' => '<b>N.B.</b> Op veel servers dien je de activatie van je toegang tot de database te <b>vragen</b> vooraleer je ze kan gebruiken. Als je geen verbinding kan maken, kijk dan na of je deze actie hebt ondernomen..',
'avis_connexion_ldap_echec_1' => 'De verbinding met de LDAP-server is mislukt.',
'avis_connexion_ldap_echec_2' => 'Ga terug naar de vorige pagina en kijk na of de ingevulde gegevens correct zijn.',
'avis_connexion_ldap_echec_3' => 'Andere mogelijkheid is om de LDAP-ondersteuning om gebruikers in te voeren niet te gebruiken.',
'avis_conseil_selection_mot_cle' => '<b>Belangrijke groep:</b> het is erg aan te bevelen een trefwoord uit deze groep te kiezen.',
'avis_deplacement_rubrique' => 'Opgelet! Deze rubiek bevat @contient_breves@ br&egrave;ve@scb@: als je haar verplaatst, gelieve dit te bevestigen door hier het vakje aan te vinken.',
'avis_destinataire_obligatoire' => 'Je dient een bestemmeling op te geven vooraleer dit bericht te verzenden.',
'avis_doublon_mot_cle' => 'Er bestaat al een sleutelwoord met dat titel. Wilt U echt dit sleutelwoord op te slaan ?', # MODIF
'avis_erreur_connexion_mysql' => 'Verbinding met de SQL connectie mislukt',
'avis_erreur_version_archive' => '<b>Opgelet! Het bestand @archive@ komt overeen met een andere
    SPIP-versie dan deze die is ge&iuml;nstalleerd.</b> Dit kan voor
 grote moeilijkheden zorgen : risico op het wissen van de databank,
 ontregeling van de website, enz. Ga niet verder met het importeren
 van het bestand. <p>Meer info kan je vinden op
 <a href="@spipnet@">
                                de documentatie van SPIP</a>.</p>', # MODIF
'avis_espace_interdit' => '<b>Toegang Verboden</b><div>SPIP is reeds ge&iuml;nstalleerd.',
'avis_lecture_noms_bases_1' => 'Het installatieprogramma heeft de namen van de ge&iuml;nstalleerde databanken niet kunnen lezen.',
'avis_lecture_noms_bases_2' => 'Geen enkele database is beschikbaar, ofwel is de functie die de databases zou moeten tonen, niet geactiveerd
  omwille van veiligheidsredenen (wat vaak het geval is bij providers).',
'avis_lecture_noms_bases_3' => 'In het andere geval is het heel waarschijnlijk dat een database met uw aanmeldingsnaam (login) bruikbaar is:',
'avis_non_acces_message' => 'Je hebt geen toegang tot dit bericht.',
'avis_non_acces_page' => 'Je hebt geen toegang tot deze pagina.',
'avis_operation_echec' => 'De bewerking is mislukt.',
'avis_operation_impossible' => 'Onmogelijke verrichting',
'avis_probleme_archive' => 'Probleem om het bestand @archive@ te lezen.',
'avis_site_introuvable' => 'Site onvindbaar.',
'avis_site_syndique_probleme' => 'Opgelet: syndicatie van deze site heeft een probleem ondervonden&nbsp;; het systeem wordt dus tijdelijk onderbroken. Controleert het adres van het bestand van syndicatie van deze site (<b>@url_syndic@</b>), en probeert nogmaals de informatie binnen te halen.',
'avis_sites_probleme_syndication' => 'Deze sites hebben een probleem met syndicatie',
'avis_sites_syndiques_probleme' => 'Deze gesyndiceerde sites hebben een probleem',
'avis_suppression_base' => 'OPGELET, het wissen van de gegevens is onomkeerbaar',
'avis_version_mysql' => 'De gebruikte SQL server versie (@version_mysql@) laat een automatische herstelling van tabellen uit de databank niet toe.',

// B
'bouton_acces_ldap' => 'LDAP toegang toevoegen',
'bouton_ajouter' => 'Toevoegen',
'bouton_ajouter_participant' => 'EEN DEELNEMER TOEVOEGEN:',
'bouton_annonce' => 'AANKONDIGING',
'bouton_annuler' => 'Annuleren',
'bouton_checkbox_envoi_message' => 'mogelijkheid om een bericht te versturen',
'bouton_checkbox_indiquer_site' => 'verplicht een website opgeven',
'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'beheerders van de site',
'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'auteurs',
'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'bezoekers van de publieke site die een bericht op het forum posten',
'bouton_checkbox_signature_unique_email' => 'een enkele handtekening per e-mail adres',
'bouton_checkbox_signature_unique_site' => 'een enkele handtekening per website',
'bouton_demande_publication' => 'De publicatie van het artikel vragen',
'bouton_desactive_tout' => 'Alles desactiveren',
'bouton_desinstaller' => 'Terugtrekken',
'bouton_effacer_index' => 'Index verwijderen',
'bouton_effacer_statistiques' => 'De statistieken uitwissen',
'bouton_effacer_tout' => 'ALLES wissen',
'bouton_envoi_message_02' => 'EEN BERICHT VERZENDEN',
'bouton_envoyer_message' => 'Definitief bericht : versturen',
'bouton_forum_petition' => 'FORUM &amp; PETITIE',
'bouton_modifier' => 'Wijzigen',
'bouton_pense_bete' => 'MEMO VOOR PERSOONLIJK GEBRUIK',
'bouton_radio_activer_messagerie' => 'Intern berichtensysteem activeren',
'bouton_radio_activer_messagerie_interne' => 'Intern berichtensysteem activeren',
'bouton_radio_activer_petition' => 'Petitie activeren',
'bouton_radio_afficher' => 'Tonen',
'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Opnemen in de lijst van online redacteuren',
'bouton_radio_articles_futurs' => 'voor toekomstige artikels alleen (geen bewerking op de databank).',
'bouton_radio_articles_tous' => 'voor alle artikels zonder uitzondering.',
'bouton_radio_articles_tous_sauf_forum_desactive' => 'voor alle artikels, behalve deze waarvan het forum is gedesactiveerd.',
'bouton_radio_desactiver_messagerie' => 'Intern berichtensysteem desactiveren',
'bouton_radio_enregistrement_obligatoire' => 'Registratie verplicht (om bijdragen te kunnen
  posten, dienen gebruikers zich eerst in te schrijven en hun e-mail adres te bezorgen).',
'bouton_radio_envoi_annonces_adresse' => 'Aankondigingen verzenden naar dit adres :',
'bouton_radio_envoi_liste_nouveautes' => 'De lijst met nieuwe bijdragen versturen',
'bouton_radio_moderation_priori' => 'Vooraf modereren (de
 bijdragen worden pas gepubliceerd na goedkeuring door een van de beheerders).',
'bouton_radio_modere_abonnement' => 'op aanvraag',
'bouton_radio_modere_posteriori' => 'nadien modereren',
'bouton_radio_modere_priori' => 'vooraf modereren',
'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Niet opnemen in de lijst van redacteuren',
'bouton_radio_non_envoi_annonces_editoriales' => 'Geen editoriale aankondigingen versturen',
'bouton_radio_non_syndication' => 'Geen syndicatie',
'bouton_radio_pas_petition' => 'Geen petitie',
'bouton_radio_petition_activee' => 'Petitie geactiveerd',
'bouton_radio_publication_immediate' => 'Onmiddellijke publicatie van berichten
 (bijdragen worden zichtbaar zodra ze verstuurd worden; beheerders kunnen nadien nog steeds
 berichten schrappen).',
'bouton_radio_sauvegarde_compressee' => 'gecomprimeerde opslag onder @fichier@',
'bouton_radio_sauvegarde_non_compressee' => 'niet-gecomprimeerde opslag onder @fichier@',
'bouton_radio_supprimer_petition' => 'De petitie verwijderen',
'bouton_radio_syndication' => 'Syndicatie :',
'bouton_redirection' => 'OMLEIDING',
'bouton_relancer_installation' => 'Installatie herbeginnen',
'bouton_restaurer_base' => 'De databank herstellen',
'bouton_suivant' => 'Volgende',
'bouton_tenter_recuperation' => 'Poging tot herstel',
'bouton_test_proxy' => 'Proxy proberen',
'bouton_vider_cache' => 'De buffer (cache) leegmaken',
'bouton_voir_message' => 'Dit bericht bekijken alvorens het goed te keuren',

// C
'cache_mode_compresse' => 'Bestanden in de buffer zijn in gecomprimeerd mode opgeslaagd.',
'cache_mode_non_compresse' => 'Bestanden in de buffer zijn in niet gecomprimeerd mode opgeslaagd.',
'cache_modifiable_webmestre' => 'Deze parameter kan door de webmaster van de site gewijzigd worden.',
'calendrier_synchro' => 'Wanneer je <b>iCal</b> compatibele agendasoftware gebruikt, kan je deze synchroniseren met informatie van deze site.',
'config_activer_champs' => 'De volgende velden activeren',
'config_choix_base_sup' => 'een basis op deze server aangeven',
'config_erreur_base_sup' => 'SPIP heeft geen toegang tot de lijst van de toegankelijke basis',
'config_info_base_sup' => 'Als u andere databases hebt om door SPIP te ondervragen, met zijn server SQL of een ander, laat het formulier hieronder, u toe om ze te verklaren. Als u bepaalde lege velden laat, zullen de identificaties van aansluiten aan de hoofdbasis gebruikt worden.',
'config_info_base_sup_disponibles' => 'De reeds navraagbare aanvullende basis:',
'config_info_enregistree' => 'De nieuwe configuratie werd geregistreerd',
'config_info_logos' => 'Elk element van de site kan een logo hebben, evenals een &#132;&nbsp;overzicht logo&nbsp;&#147;',
'config_info_logos_utiliser' => 'De logo\'s gebruiken',
'config_info_logos_utiliser_non' => 'Niet de logo\'s gebruiken',
'config_info_logos_utiliser_survol' => 'De logo\'s van overzicht gebruiken',
'config_info_logos_utiliser_survol_non' => 'Niet de logo\'s van overzicht gebruiken',
'config_info_redirection' => 'Door deze keuze te activeren, zult u virtuele artikelen kunnen cre&euml;ren, eenvoudige verwijzingen van gepubliceerde artikelen over andere sites of buiten SPIP.',
'config_redirection' => 'Virtuele artikelen',
'config_titre_base_sup' => 'Verklaring van een aanvullende basis',
'config_titre_base_sup_choix' => 'Kiest een aanvullende basis',
'connexion_ldap' => 'Aansluiten :',
'copier_en_local' => 'Plaatselijk kopi&euml;ren',

// D
'date_mot_heures' => 'uur',
'diff_para_ajoute' => 'Toegevoegde paragraaf',
'diff_para_deplace' => 'Verplaatste paragraaf',
'diff_para_supprime' => 'Verwijderde paragraaf',
'diff_texte_ajoute' => 'Toegevoegde tekst',
'diff_texte_deplace' => 'Verplaatste tekst',
'diff_texte_supprime' => 'Verwijderde tekst',
'double_clic_inserer_doc' => 'Dubbelklik om deze snelkoppeling in de tekst te lassen.',

// E
'email' => 'e-mail',
'email_2' => 'e-mail:',
'en_savoir_plus' => 'Meer weten hierover',
'entree_adresse_annuaire' => 'Plaats van het adresboek',
'entree_adresse_email' => 'Uw e-mail adres',
'entree_adresse_fichier_syndication' => 'Adres van het bestand voor syndicatie&nbsp;:',
'entree_adresse_site' => '<b>website adres</b> [verplicht]',
'entree_base_donnee_1' => 'Adres van de databank',
'entree_base_donnee_2' => '(Vaak komt dit adres overeen met dat van je website, soms is het gewoon de vermelding&laquo;localhost&raquo; of kan je het veld blanco laten.)',
'entree_biographie' => 'Korte biografie in enkele woorden.',
'entree_breve_publiee' => 'Dient dit bericht te worden gepubliceerd ?',
'entree_chemin_acces' => '<b>Invullen</b> van de toegangscode&nbsp;:',
'entree_cle_pgp' => 'Je PGP-sleutel',
'entree_contenu_rubrique' => '(Inhoud van de rubriek in enkele woorden)',
'entree_description_site' => 'Site beschrijving',
'entree_identifiants_connexion' => 'Je verbindingsgegevens...',
'entree_informations_connexion_ldap' => 'Vul hier de gegevens in om verbinding te maken met het LDAP adresboek.
  Deze gegevens kan je bekomen bij de systeem- of netwerkbeheerder.',
'entree_infos_perso' => 'Wie ben je ?',
'entree_interieur_rubrique' => 'In de rubriek:',
'entree_liens_sites' => '<b>Hypertext link</b> (verwijzing, te bezoeken website ...)',
'entree_login' => 'Je login',
'entree_login_connexion_1' => 'De login voor de verbinding',
'entree_login_connexion_2' => '(Komt soms overeen met je FTP-loginnaam; soms wordt dit niet ingevuld)',
'entree_login_ldap' => 'Eerste LDAP-login',
'entree_mot_passe' => 'Je paswoord',
'entree_mot_passe_1' => 'Paswoord voor deze verbinding ',
'entree_mot_passe_2' => '(Komt vaak overeen met je paswoord voor FTP-toegang; soms kan je dit ook blanco laten)',
'entree_nom_fichier' => 'Vul hier de naam in van het betand @texte_compresse@:',
'entree_nom_pseudo' => 'je naam of bijnaam',
'entree_nom_pseudo_1' => '(je naam of bijnaam)',
'entree_nom_site' => 'je websitename',
'entree_nouveau_passe' => 'nieuw paswoord',
'entree_passe_ldap' => 'Paswoord',
'entree_port_annuaire' => 'Het poortnummer van het adresboek',
'entree_signature' => 'Handtekening',
'entree_texte_breve' => 'Tekst van het bericht',
'entree_titre_obligatoire' => '<b>Titel</b> [verplicht]<br />',
'entree_url' => 'Je website-adres (URL)',
'erreur_plugin_desinstalation_echouee' => 'La d&eacute;sinstallation du plugin a echou&eacute;e. Vous pouvez n&eacute;anmoins le desactiver.', # MODIF
'erreur_plugin_fichier_absent' => 'Bestand ontbreekt',
'erreur_plugin_fichier_def_absent' => 'Definitiebestand ontbreekt',
'erreur_plugin_nom_fonction_interdit' => 'Functienaam verboden',
'erreur_plugin_nom_manquant' => 'Naam van de ontbrekende plugin',
'erreur_plugin_prefix_manquant' => 'Ruimte van plugin naam is niet bepaalde ',
'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; ontbreekt in het definitiebestand',
'erreur_plugin_version_manquant' => 'Versie van de ontbrekende plugin',

// F
'forum_info_original' => 'origineel',

// H
'htaccess_a_simuler' => 'Avertissement: la configuration de votre serveur HTTP ne tient pas compte des fichiers @htaccess@. Pour pouvoir assurer une bonne s&eacute;curit&eacute;, il faut que vous modifiez cette configuration sur ce point, ou bien que les constantes @constantes@ (d&eacute;finissables dans le fichier mes_options.php) aient comme valeur des r&eacute;pertoires en dehors de @document_root@.', # NEW
'htaccess_inoperant' => 'htaccess inop&eacute;rant', # NEW

// I
'ical_info1' => 'Deze pagina toont de verschillende wijzen waarop je contact kan houden met het gebeuren van deze website.',
'ical_info2' => 'Voor meer inlichtingen over al deze technieken, aarzelt niet om <a href=" @spipnet@" te raadplegen >de documentatie van SPIP</a>.',
'ical_info_calendrier' => 'Twee kalenders zijn beschikbaar. De eerste geeft een overzicht van alle gepubliceerde artikels. De tweede bevat editoriale berichten en je meest recente priv&eacute;-berichten&nbsp;: deze tweede kalender is afgeschermd voor andere gebruikers door een persoonlijke sleutel die je op elk moment kan wijzigen door je paswoord te vernieuwen.',
'ical_lien_rss_breves' => 'Syndication van kort van de site',
'ical_methode_http' => 'Downloaden',
'ical_methode_webcal' => 'Synchronisatie (webcal://)',
'ical_texte_js' => 'Met een javascriptregel kan je op eenvoudige wijze de meest recente artikels van deze site weergeven op een andere site die je beheert.',
'ical_texte_prive' => 'Deze kalender is voor persoonlijk gebruik en houdt je op de hoogte van je eigen editoriale activiteit (taken en persoonlijke afspraken, voorgestelde artikels en nieuwsberichten...).',
'ical_texte_public' => 'Via deze kalender kan je de publieke activiteit van de site volgen (gepubliceerde artikels en berichten).',
'ical_texte_rss' => 'Je kan de nieuwe berichten van de site overnemen (syndiceren) op een andere site in eender welke bestandslezer via het formaat XML/RSS (Rich Site Summary). Dit is hetzelfde formaat dat SPIP toelaat nieuws over te nemen van andere sites die een uitwisselbaar formaat hanteren (gesyndiceerde sites).',
'ical_titre_js' => 'Javascript',
'ical_titre_mailing' => 'Mailinglijst',
'ical_titre_rss' => 'Syndicatiebestanden',
'icone_activer_cookie' => 'De toegangskoekie activeren',
'icone_admin_plugin' => 'Plugin beheer',
'icone_afficher_auteurs' => 'Auteurs tonen',
'icone_afficher_visiteurs' => 'Bezoekers tonen',
'icone_arret_discussion' => 'Niet langer deelnemen aan deze discussie',
'icone_calendrier' => 'Kalender',
'icone_creation_groupe_mots' => 'Een nieuwe groep van trefwoorden aanmaken',
'icone_creation_mots_cles' => 'Een nieuw trefwoord aanmaken',
'icone_creer_auteur' => 'Een nieuwe auteur aanmaken en koppelen aan dit artikel',
'icone_creer_mot_cle' => 'Een nieuw trefwoord aanmaken en koppelen aan dit artikel',
'icone_creer_mot_cle_breve' => 'Een nieuw sleutelwoord cre&euml;ren en het binden aan dit br&egrave;ve',
'icone_creer_mot_cle_rubrique' => 'Een nieuw sleutelwoord cre&euml;ren en het binden aan deze rubriek',
'icone_creer_mot_cle_site' => 'Een nieuw sleutelwoord cre&euml;ren en het binden aan deze site',
'icone_creer_rubrique_2' => 'Een nieuwe rubriek aanmaken',
'icone_ecrire_nouvel_article' => 'De berichten van deze rubriek',
'icone_envoyer_message' => 'Bericht verzenden',
'icone_evolution_visites' => 'Evolutie van de bezoeken<br />@visites@ bezoeken',
'icone_modif_groupe_mots' => 'Deze groep van trefwoorden wijzigen',
'icone_modifier_article' => 'Dit artikel wijzigen',
'icone_modifier_breve' => 'Dit bericht wijzigen',
'icone_modifier_message' => 'Bericht wijzigen',
'icone_modifier_mot' => 'Dit sleutelwoord wijzigen',
'icone_modifier_rubrique' => 'Deze rubriek wijzigen',
'icone_modifier_site' => 'Deze site wijzigen',
'icone_poster_message' => 'Een bericht versturen',
'icone_publier_breve' => 'Dit nieuwsbericht publiceren',
'icone_referencer_nouveau_site' => 'Een nieuwe site koppelen',
'icone_refuser_breve' => 'Dit nieuwsbericht weigeren',
'icone_relancer_signataire' => 'De ondertekenaar weer op gang brengen',
'icone_retour' => 'Terug',
'icone_retour_article' => 'Terug naar artikel',
'icone_suivi_forum' => 'Opvolging van het publieke forum: @nb_forums@&nbsp;bijdrage(n)',
'icone_supprimer_cookie' => 'De toegangskoekie verwijderen',
'icone_supprimer_groupe_mots' => 'Deze groep wissen',
'icone_supprimer_rubrique' => 'Deze rubriek wissen',
'icone_supprimer_signature' => 'Deze naam wissen',
'icone_valider_signature' => 'Deze naam goedkeuren',
'icone_voir_sites_references' => 'Gekoppelde sites zien',
'icone_voir_tous_mots_cles' => 'Alle trefwoorden bekijken',
'image_administrer_rubrique' => 'Je kan deze rubriek beheren',
'info_1_article' => '1 artikel',
'info_1_breve' => '1 bericht',
'info_1_site' => '1 site',
'info_activer_cookie' => 'Je kan een <b>toegangskoekie</b> activeren,  waardoor je makkelijk kan wisselen
 tussen de het publieke en het private deel van de website.',
'info_activer_forum_public' => '<i>Om de openbare forums te activeren, dien je een standaardinstelling
 voor het modereren te kiezen :</i>',
'info_admin_gere_rubriques' => 'Deze auteur beheert de volgende rubrieken :',
'info_admin_gere_toutes_rubriques' => 'Deze auteur beheert<b>alle rubrieken</b>.',
'info_admin_statuer_webmestre' => 'Donner &agrave; cet administrateur les droits de webmestre', # NEW
'info_admin_webmestre' => 'Cet administrateur est <b>webmestre</b>', # NEW
'info_administrateur' => 'Beheerder',
'info_administrateur_1' => 'Beheerder',
'info_administrateur_2' => 'van de website (<i>voorzichtig gebruiken</i>)',
'info_administrateur_site_01' => 'Als je beheerder bent van deze site, gelieve',
'info_administrateur_site_02' => 'deze koppeling aan te klikken',
'info_administrateurs' => 'Beheerders',
'info_administrer_rubrique' => 'Je kan deze rubriek beheren',
'info_adresse' => 'aan/naar het adres:',
'info_adresse_email' => 'E-MAIL ADRES:',
'info_adresse_url' => 'Adres (URL) van de website',
'info_afficher_visites' => 'Toon het aantal bezoeken voor:',
'info_affichier_visites_articles_plus_visites' => 'Bezoekers tonen voor <b>de meest bezochte artikels sinds het begin:</b>',
'info_aide_en_ligne' => 'ONLINE HELP VAN SPIP',
'info_ajout_image' => 'Als je afbeeldingen als bijlage aan een document toevoegt,
  kan SPIP hiervan automatisch miniaturen aanmaken.
  Hierdoor kan je bvb. automatisch een fotogalerij of portfolio aanmaken.
',
'info_ajout_participant' => 'De volgende deelnemer is toegevoegd:',
'info_ajouter_rubrique' => 'Een nieuwe rubriek toevoegen om te beheren:',
'info_annonce_nouveautes' => 'Aankondiging van nieuwigheden',
'info_anterieur' => 'vorige',
'info_appliquer_choix_moderation' => 'Pas deze moderatievorm toe ::',
'info_article' => 'artikel',
'info_article_2' => 'artikels',
'info_article_a_paraitre' => 'Te publiceren artikels met postdatering',
'info_articles_02' => 'artikels',
'info_articles_2' => 'Artikels',
'info_articles_auteur' => 'Artikels van deze auteur',
'info_articles_lies_mot' => 'Artikels gekoppeld aan dit trefwoord',
'info_articles_trouves' => 'Gevonden artikels',
'info_articles_trouves_dans_texte' => 'Gevonden artikels (in de tekst)',
'info_attente_validation' => 'Je artikels die op goedkeuring wachten',
'info_aujourdhui' => 'vandaag:',
'info_auteur_message' => 'AUTEUR VAN HET BERICHT:',
'info_auteurs' => 'De auteurs',
'info_auteurs_par_tri' => 'Auteur@partri@',
'info_auteurs_trouves' => 'Gevonden auteurs',
'info_authentification_externe' => 'Externe authenticatie',
'info_avertissement' => 'Waarschuwing',
'info_barre_outils' => 'met zijn werktuigen staaf ?',
'info_base_installee' => 'De structuur van je databank is ge&iuml;nstalleerd.',
'info_base_restauration' => 'De databank wordt hersteld.',
'info_bloquer' => 'blokkeren',
'info_breves' => 'Werkt je website met het systeem van berichten?',
'info_breves_03' => 'nieuwsberichten',
'info_breves_liees_mot' => 'Berichten gekoppeld aan dit trefwoord',
'info_breves_touvees' => 'Gevonden berichten',
'info_breves_touvees_dans_texte' => 'Gevonden berichten (in de tekst)',
'info_changer_nom_groupe' => 'De naam van deze groep veranderen:',
'info_chapeau' => 'Kop',
'info_chapeau_2' => 'Kop&nbsp;:',
'info_chemin_acces_1' => 'Opties : <b>Toegang tot het adresboek</b>',
'info_chemin_acces_2' => 'Je dient de toegang tot de gegevens uit het adresboek in te stellen. Zonder deze instellingen is het ONmogelijk de gebruikersprofielen in dit adresboek te lezen.',
'info_chemin_acces_annuaire' => 'Opties : <b>Toegang in het adresboek',
'info_choix_base' => 'Derde stap:',
'info_classement_1' => '<sup>ste</sup> op @liste@',
'info_classement_2' => '<sup>de</sup> @liste@',
'info_code_acces' => 'Vergeet je eigen toegangscode niet!',
'info_comment_lire_tableau' => 'Hoe lees je deze tabel',
'info_compresseur_gzip' => '<b>N.&nbsp;B.&nbsp;:</b> Hij wordt aanbevolen om eerst te controleren of leverancier de scripts php&nbsp; reeds systematisch samenperst; daarvoor, kunt u bijvoorbeeld de volgende dienst gebruiken&nbsp;: @testgzip@',
'info_compresseur_texte' => 'Als uw server de bladzijdes HTML niet automatisch samendrukt om ze te verzenden naar de internauten, kunt u deze samendrukking proberen te forceren om het gewicht van de gedownloade bladzijdes te verminderen. <b>Aandacht</b>: dat kan bepaalde servers aanzienlijk vertragen.',
'info_compresseur_titre' => 'Optimaliseringen en samendrukking',
'info_config_forums_prive' => 'In de particuliere ruimte van de site, kunt u verschillende soorten forums activeren&nbsp;:',
'info_config_forums_prive_admin' => 'Een forum dat voor de beheerders van de site is gereserveerd&nbsp;:',
'info_config_forums_prive_global' => 'Een globaal forum, open voor alle redacteuren&nbsp;:',
'info_config_forums_prive_objets' => 'Een forum onder elk artikel, kort, verwezen site, enz.&nbsp;:',
'info_config_suivi' => 'Wanneer dit adres van een rondzendlijst is, kan je hieronder het adres opgeven waarlangs deelnemers van de site zich kunnen inschrijven. Dit adres kan een URL zijn (bvb. het webadres voor het inschrijving op de mailinglist), of een e-mailadres met een onderwerp (bvb. <tt>@adresse_suivi@?subject=subscribe</tt>):',
'info_config_suivi_explication' => 'Je kan je op de mailinglijst van deze site inschrijven. Je zal dan via e-mail een aankondiging ontvangen van artikels en nieuwsberichten die voor publicatie werden voorgesteld.',
'info_confirmer_passe' => 'Bevestig het nieuwe paswoord :',
'info_conflit_edition_avis_non_sauvegarde' => 'Aandacht, de volgende velden werden voorts gewijzigd. Uw wijzigingen op deze velden werden dus niet geregistreerd.',
'info_conflit_edition_differences' => 'Verschillen&nbsp;:',
'info_conflit_edition_version_enregistree' => 'De geregistreerde versie&nbsp;:',
'info_conflit_edition_votre_version' => 'Uw versie&nbsp;:',
'info_connexion_base' => 'Proef van aansluiten aan de basis',
'info_connexion_base_donnee' => 'Aansluiten aan uw database',
'info_connexion_ldap_ok' => 'De LDAP-verbinding is gelukt.</b><p> Je kan de volgende stap zetten.</p>', # MODIF
'info_connexion_mysql' => 'Uw aansluiten SQL',
'info_connexion_ok' => 'De verbinding is geslaagd.',
'info_contact' => 'Contact',
'info_contenu_articles' => 'Inhoud van de artikels',
'info_creation_mots_cles' => 'Cre&euml;er en configureer hier de trefwoorden van de site',
'info_creation_paragraphe' => '(Om een nieuwe paragraaf aan te maken, laat je gewoon enkele lijnen blanco.)',
'info_creation_rubrique' => 'Alvorens artikelen te kunnen schrijven,<br /> u moet een rubriek minstens cre&euml;ren.<br />',
'info_creation_tables' => 'Oprichting van tabellen in de databank',
'info_creer_base' => '<b>Cre&euml;ren</b> een nieuw databank:',
'info_dans_groupe' => 'In de groep:',
'info_dans_rubrique' => 'In de rubriek:',
'info_date_publication_anterieure' => 'Datum van eerdere redactie :',
'info_date_referencement' => 'DATUM VAN DE KOPPELING VAN DEZE SITE:',
'info_delet_mots_cles' => 'Je hebt gevraagd het trefwoord 
<b>@titre_mot@</b> (@type_mot@) te verwijderen. Dit trefwoord is gekoppeld aan 
<b>@texte_lie@</b>, je dient je beslissing te bevestigen:',
'info_derniere_etape' => 'Gedaan !',
'info_derniere_syndication' => 'De laatste syndicatie van deze site heeft plaatsgevonden op ',
'info_derniers_articles_publies' => 'Je meest recente online artikels',
'info_desactiver_forum_public' => 'Het gebruik van de publieke forums desactiveren.
De publieke forums kunnen per artikel toegestaan worden
; Ze worden niet toegestaan op de rubrieken en berichten, enz.',
'info_desactiver_messagerie_personnelle' => 'Je kan het interne berichtensysteem op deze site aan- of uitzetten.',
'info_descriptif' => 'Beschrijving:',
'info_desinstaller_plugin' => 'schaft de gegevens af en d&eacute;sactive plugin',
'info_discussion_cours' => 'Lopende discussies',
'info_ecrire_article' => 'Alvorens een artikel te kunnen schrijven, dien je minimaal &eacute;&eacute;n rubriek aanmaken.',
'info_email_envoi' => 'Verzendadres (optioneel)',
'info_email_envoi_txt' => 'Geef hieronder het adres op dat gebruikt wordt voor het versturen van e-mails. (Standaard wordt het adres van de bestemmeling als verzendadres gebruikt.)&nbsp;:',
'info_email_webmestre' => 'E-mailadres van de webmaster (optioneel)',
'info_entrer_code_alphabet' => 'Vul de alfabetcode in die je wil gebruiken:',
'info_envoi_email_automatique' => 'Automatisch verzenden van e-mails',
'info_envoi_forum' => 'Versturen van de forums aan de auteurs van de artikels',
'info_envoyer_maintenant' => 'Nu versturen',
'info_erreur_restauration' => 'Herstelfout : onbestaande map.',
'info_etape_suivante' => 'Naar de volgende stap ',
'info_etape_suivante_1' => 'Je kan de volgende stap zetten.',
'info_etape_suivante_2' => 'Je kan de volgende stap zetten.',
'info_exportation_base' => 'Uitvoer van de databank naar @archive@',
'info_facilite_suivi_activite' => 'Om de opvolging en redactie van artikels te
 vergemakkelijken, kan SPIP mails versturen -bijvoorbeeld naar een mailinglist van redacteurs-
 met de aankondiging van vragen voor publicatie of goedgekeurde publicaties.',
'info_fichiers_authent' => 'Verificatiebestand ".htpasswd"',
'info_fonctionnement_forum' => 'Werking van het forum:',
'info_forum_administrateur' => 'Forum van de beheerders',
'info_forum_interne' => 'intern forum',
'info_forum_ouvert' => 'Een forum in het private deel van de site is toegankelijk
  voor alle geregistreerde redacteurs. Hieronder kan je een
  extra forum aanmaken dat alleen bestemd is voor de beheerders.',
'info_forum_statistiques' => 'Statistieken van de bezoeken',
'info_forums_abo_invites' => 'Je site bevat forums met abonnement; bezoekers worden dus op de publieke site verzocht zich in te schrijven.',
'info_gauche_admin_effacer' => '<b>Deze pagina is enkel toegankelijk voor beheerders van de site.</b><p> Ze geeft toegang tot verschillende onderhoudstaken. Voor sommige taken is een afzonderlijke aanmelding tot de site via FTP vereist.</p>', # MODIF
'info_gauche_admin_tech' => '<b>Deze pagina is enkel toegankelijk voor beheerders van de site.</b><p> Ze geeft toegang tot allerlei technische onderhoudstaken.
 Voor het uitvoeren van sommige taken zijn een afzonderlijke aanmelding en toegang tot je site via FTP nodig.</p>', # MODIF
'info_gauche_admin_vider' => '<b>Deze pagina is enkel toegankelijk voor beheerders van de site.</b><p> Ze geeft toegang tot allerlei technische onderhoudstaken.
 Voor het uitvoeren van sommige taken zijn een afzonderlijke aanmelding en toegang tot je site via FTP vereist.</p>', # MODIF
'info_gauche_auteurs' => 'Je vindt hier alle auteurs van de site.
 Hun status is te herkennen aan de kleur van het icoontje (beheerder = groen; redacteur = geel).',
'info_gauche_auteurs_exterieurs' => 'Externe auteurs, zonder toegang tot de site, zijn aangeduid met een blauw icoontje;
  Gewiste auteurs hebben een vuilnisbakje naast hun naam staan.',
'info_gauche_messagerie' => 'Het berichtensysteem laat toe om berichten uit te wisselen tussen redacteurs, memo\'s (voor persoonlijk gebruik) te bewaren of aankondigingen te tonen op de beginpagina van de priv&eacute;-ruimte (als je beheerder bent).',
'info_gauche_numero_auteur' => 'NUMMER AUTEUR',
'info_gauche_numero_breve' => 'NUMMER BERICHT',
'info_gauche_statistiques_referers' => 'Deze pagina toont een lijst met <i>referers</i>, tw. sites die een koppeling bevatten naar je eigen site, enkel voor vandaag en gisteren: de lijst wordt elke 24 uur opnieuw aangemaakt.',
'info_gauche_suivi_forum' => 'De pagina voor <i>opvolging van de forums</i> is een plek voor beheer van je site (en dus niet voor discussie of redactie). Alle bijdragen aan het publieke forum aansluitend op die artikel worden getoond en kan je hier beheren.',
'info_gauche_suivi_forum_2' => 'De bladzijde van <i>gevolgd door de forums</i> is een werktuig van beleid van uw site (en niet een ruimte van discussie of opstellen). Zij geeft alle bijdragen van de forums van de site te kennen, evengoed laten deze van de openbare site als van de particuliere ruimte toe en u om deze bijdragen te beheren.',
'info_gauche_visiteurs_enregistres' => 'Hier zal je de geregistreerde bezoekers van de
 publieke site vinden (forums met inschrijving).',
'info_generation_miniatures_images' => 'Aanmaak van de miniatuurafbeeldingen',
'info_gerer_trad' => 'De koppelingen voor vertaling beheren ?',
'info_groupe_important' => 'Belangrijke groep',
'info_hebergeur_desactiver_envoi_email' => 'Sommige hostingbedrijven staan het automatisch versturen van e-mails door hun servers niet toe. In dat geval zullen de volgende functionaliteiten van SPIP niet werken.',
'info_hier' => 'gisteren:',
'info_historique' => 'Revisies&nbsp;:',
'info_historique_activer' => 'Activeren van het opvolgen van de revisies',
'info_historique_affiche' => 'Deze versie weergeven',
'info_historique_comparaison' => 'vergelijking',
'info_historique_desactiver' => 'Het opvolgen van de revisies desactiveren',
'info_historique_lien' => 'De geschiedenis van de wijzigingen weergeven',
'info_historique_texte' => 'Met de opvolging van de revisies is het mogelijk de geschiedenis van alle wijzigingen aan een artikel bij te houden, en de verschillende tussen opeenvolgende versies weer te geven.',
'info_historique_titre' => 'Opvolging van de revisies',
'info_identification_publique' => 'Je publieke identiteit...',
'info_image_process' => 'Kies de beste methode om een miniatuurafbeelding te maken door op de bijhorende afbeelding te klikken.',
'info_image_process2' => '<b>N.B.</b> <i>Wanneer geen enkel beeld wordt getoond, betekent dit dat de server van je website niet is ingesteld om deze tools te gebruiken. Als je van deze functies gebruik wil maken, dien je de technische verantwoordelijke van de server te contacteren en te vragen naar &laquo;GD&raquo; of &laquo;Imagick&raquo; extensies.</i>',
'info_images_auto' => 'Beelden automatisch berekend',
'info_informations_personnelles' => 'Persoonlijke gegevnes',
'info_inscription_automatique' => 'Automatische inschrijving van nieuwe redacteurs',
'info_jeu_caractere' => 'Tekenset van de site',
'info_jours' => 'dagen',
'info_laisser_champs_vides' => 'velden leeglaten)',
'info_langues' => 'Talen van de site',
'info_ldap_ok' => 'De LDAP-autentificatie is ge&iuml;nstalleerd',
'info_lien_hypertexte' => 'Hypertekst koppeling :',
'info_liens_syndiques_1' => 'gesyndiceerde koppelingen',
'info_liens_syndiques_2' => 'wachten op goedkeuring.',
'info_liens_syndiques_3' => 'forums',
'info_liens_syndiques_4' => 'zijn',
'info_liens_syndiques_5' => 'forum',
'info_liens_syndiques_6' => 'is',
'info_liens_syndiques_7' => 'nog niet goedgekeurd',
'info_liste_redacteurs_connectes' => 'Lijst met online redacteuren',
'info_login_existant' => 'Deze login is reeds in gebruik',
'info_login_trop_court' => 'Login te kort.',
'info_logos' => 'De logo\'s',
'info_maximum' => 'maximum:',
'info_meme_rubrique' => 'In dezelfde rubriek',
'info_message' => 'Bericht van',
'info_message_efface' => 'GEWIST BERICHT',
'info_message_en_redaction' => 'Je berichten in redactie',
'info_message_technique' => 'Technisch bericht :',
'info_messagerie_interne' => 'Intern berichtensysteem',
'info_mise_a_niveau_base' => 'update van je SQL-databank',
'info_mise_a_niveau_base_2' => '{{Opgelet!}} Je hebt een SPIP-versie ge&iuml;nstalleerd
 die {ouder} is dan diegene die zich eerder op deze
 site bevond.: je databank loopt hierdoor het risico
 beschadigd te worden waardoor je site niet meer zal
 functioneren.<br />{{Herinstalleer de SPIP-bestanden.}}',
'info_mode_fonctionnement_defaut_forum_public' => 'Standaardwerkwijze van de publieke forums',
'info_modifier_auteur' => 'De auteur wijzigen :',
'info_modifier_breve' => 'Bericht wijzigen :',
'info_modifier_mot' => 'Het sleutelwoord wijzigen :',
'info_modifier_rubrique' => 'De rubriek wijzigen:',
'info_modifier_titre' => 'Wijzigen : @titre@',
'info_mon_site_spip' => 'Mijn SPIP-site',
'info_mot_sans_groupe' => '(Woorden zonder groep...)',
'info_moteur_recherche' => 'Ge&iuml;ntegreerde zoekmachine',
'info_mots_cles' => 'Trefwoorden',
'info_mots_cles_association' => 'Trefwoorden uit deze groep kunnen verbonden worden met:',
'info_moyenne' => 'gemiddeld:',
'info_multi_articles' => 'Taalmenu voor artikels instellen?',
'info_multi_cet_article' => 'Gebruikte taal in dit artikel is:',
'info_multi_langues_choisies' => 'Kies hierna welke talen ter beschikking staan van de redacteurs van je site.
  Talen die al worden gebruikt (vooraan in de lijst getoond) kunnen niet geschrapt worden.
',
'info_multi_rubriques' => 'Taalmenu toepassen op de rubrieken?',
'info_multi_secteurs' => '... enkel voor de rubrieken in de hoofdmap?',
'info_nom' => 'Naam',
'info_nom_destinataire' => 'Naam van de bestemmeling',
'info_nom_site' => 'naam van je site',
'info_nom_site_2' => '<b>Naam van de website</b> [verplicht]',
'info_nombre_articles' => '@nb_articles@ artikels,',
'info_nombre_breves' => '@nb_breves@ berichten,',
'info_nombre_partcipants' => 'DEELNEMERS AAN DE DISCUSSIE :',
'info_nombre_rubriques' => '@nb_rubriques@ rubrieken, ',
'info_nombre_sites' => '@nb_sites@ sites,',
'info_non_deplacer' => 'Niet verplaatsen...',
'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP kan regelmatig een bericht versturen om de laatste  nieuwigheden van de site te melden
   (recent gepubliceerde artikels en berichten).',
'info_non_envoi_liste_nouveautes' => 'De lijst met nieuwigheden niet versturen',
'info_non_modifiable' => 'kan niet gewijzigd worden',
'info_non_suppression_mot_cle' => 'Ik wil dit trefwoord niet verwijderen.',
'info_notes' => 'Opmerkingen',
'info_nouveaux_message' => 'Nieuwe berichten',
'info_nouvel_article' => 'Nieuw artikel',
'info_nouvelle_traduction' => 'Nieuwe vertaling&nbsp;:',
'info_numero_article' => 'ARTIKEL NUMMER:',
'info_obligatoire_02' => '[Verplicht]',
'info_option_accepter_visiteurs' => 'Inschrijving van bezoekers van de publieke site aanvaarden',
'info_option_email' => 'Wanneer een bezoeker van de site een nieuw bericht in het forum opstelt dat met een artikel wordt verenigd, kunnen de auteurs van het artikel van dit bericht per e-mail verwittigd worden. Voor elk soort forum aangeven als men deze keuze moet gebruiken.',
'info_option_faire_suivre' => 'Berichten van het forum bezorgen aan de auteurs van de artikels',
'info_option_ne_pas_accepter_visiteurs' => 'Inschrijving van bezoekers weigeren',
'info_option_ne_pas_faire_suivre' => 'Berichten uit de forums niet laten opvolgen',
'info_options_avancees' => 'GEAVANCEERDE OPTIES',
'info_ortho_activer' => 'Spellingcontrole inschakelen',
'info_ortho_desactiver' => 'Spellingcontrole uitschakelen',
'info_ou' => 'of...',
'info_oui_suppression_mot_cle' => 'Ik wil dit trefwoord definitief verwijderen.',
'info_page_interdite' => 'Verboden pagina',
'info_par_nom' => 'per naam',
'info_par_nombre_article' => 'volgens aantal artikels',
'info_par_statut' => 'per statuut',
'info_par_tri' => '\'(per @tri@)\'',
'info_pas_de_forum' => 'geen forum',
'info_passe_trop_court' => 'Paswoord te kort.',
'info_passes_identiques' => 'Beide paswoorden zijn niet identiek.',
'info_pense_bete_ancien' => 'Voorbije memos', # MODIF
'info_plus_cinq_car' => 'Meer dan 5 karakters',
'info_plus_cinq_car_2' => '(Meer dan 5 karakters)',
'info_plus_trois_car' => '(Meer dan 3 karakters)',
'info_popularite' => 'populariteit:&nbsp;@popularite@; bezoeken:&nbsp;@visites@',
'info_popularite_2' => 'populariteit van de site:',
'info_popularite_3' => 'populariteit:&nbsp;@popularite@; bezoeken:&nbsp;@visites@',
'info_popularite_4' => 'populariteit:&nbsp;@popularite@; bezoeken:&nbsp;@visites@',
'info_post_scriptum' => 'Post-Scriptum',
'info_post_scriptum_2' => 'Post-scriptum :',
'info_pour' => 'voor',
'info_preview_admin' => 'Enkel beheerders kunnen de site in preview zien',
'info_preview_comite' => 'Alle redacteurs kunnen de site in preview zien',
'info_preview_desactive' => 'Preview van de site is uitgeschakeld',
'info_preview_texte' => 'Nu is het ook mogelijk om de site in preview mode te zien, alsof alle artikels en berichten (indien ze tenminste werden &laquo;&nbsp;voorgesteld voor publicatie&nbsp;&raquo;) ook echt waren gepubliceerd.Dient deze mogelijkheid te worden voorzien voor de beheerders alleen, voor alle redacteurs of voor niemand&nbsp;?',
'info_principaux_correspondants' => 'Je belangrijkste correspondenten',
'info_procedez_par_etape' => 'volg stap voor stap',
'info_procedure_maj_version' => 'de procedure voor updaten die nodig is om de databank aan te passen
 aan de nieuwe versie van SPIP.',
'info_proxy_ok' => 'Test van proxy geslaagde.',
'info_ps' => 'N.B.',
'info_publier' => 'publiceren',
'info_publies' => 'Je gepubliceerde artikels',
'info_question_accepter_visiteurs' => 'Als de sjablonen van je site voorzien dat bezoekers zich kunnen registreren zonder toegang tot de priv&eacute;-ruimte, activeer dan de volgende optie&nbsp;:',
'info_question_activer_compactage_css' => 'Wilt u de verdichting van de stijl bladen  activeren (CSS) ?',
'info_question_activer_compactage_js' => 'Wilt u de verdichting van de scripts activeren (javascript) ?',
'info_question_activer_compresseur' => 'Wilt u de samendrukking van de stroom activeren HTTP ?',
'info_question_gerer_statistiques' => 'Dient je site bezoekersstatiestieken aan te maken ?',
'info_question_inscription_nouveaux_redacteurs' => 'Aanvaard je inschrijvingen van nieuwe redacteuren vanop
 de publieke site? Indien wel, dan kunnen bezoekers
 zich via een geautomatiseerd formulier inschrijven en
 toegang krijgen tot de priv&eacute;-ruimte om zelf artikels
 voor te stellen.<blockquote><i>Bij inschrijving zal een
 gebruiker een automatische e-mail ontvangen met daarin
 de toeganscode voor de site. Sommige hostingproviders
 blokkeren echter het versturen van e-mail vanaf hun
 servers : in dat geval is een automatische inschrijving
 niet mogelijk.</i></blockquote>',
'info_question_mots_cles' => 'Wil je gebruik maken van trefwoorden op je site?',
'info_question_proposer_site' => 'Wie kan referentiesites voorstellen?',
'info_question_utilisation_moteur_recherche' => 'Wil je gebruik maken van de geintegreerde zoekmachine van SPIP ?
 (niet-activeren hiervan versnelt de werking van het systeem.)',
'info_question_vignettes_referer' => 'Wanneer u de statistieken raadpleegt, kunt u korte overzichten van de plaatsen van oorsprong van de bezoeken zichtbaar maken',
'info_question_vignettes_referer_non' => 'Niet de vangsten van de sites van oorsprong van de bezoeken te kennen geven',
'info_question_vignettes_referer_oui' => 'De vangsten van de siten van oorsprong van de bezoeken te kennen geven',
'info_question_visiteur_ajout_document_forum' => 'Als u de bezoekers wilt machtigen om documenten (beelden, klanken…) samen te voegen aan hun berichten van forum, de lijst van de uitbreidingen van documenten hieronder aangeven toegelaten voor de ex forums (: gif, jpg, png, mp3).',
'info_question_visiteur_ajout_document_forum_format' => 'Als u alle soorten documenten toestaan wilt die als betrouwbaar door SPIP, een ster worden beschouwd, zetten. Om niets toe te staan, niets aangeven.',
'info_qui_attribue_mot_cle' => 'De woorden uit deze groep kunnen toegekend worden door:',
'info_racine_site' => 'Begin van de site',
'info_recharger_page' => 'Gelieve deze pagina binnen enkele ogenblikken te herladen.',
'info_recherche_auteur_a_affiner' => 'Teveel resultaten voor "@cherche_auteur@" ; gelieve de zoekopdracht te verfijnen.',
'info_recherche_auteur_ok' => 'Meerdere redacteurs gevonden voor "@cherche_auteur@":',
'info_recherche_auteur_zero' => 'Geen resultaat voor &laquo;&nbsp;@cherche_auteur@&nbsp;&raquo;.',
'info_recommencer' => 'Proberd nog eens alstublieft.',
'info_redacteur_1' => 'Redacteur',
'info_redacteur_2' => 'met toegang tot de priv&eacute;-ruimte(<i>aanbevolen</i>)',
'info_redacteurs' => 'Redacteurs',
'info_redaction_en_cours' => 'IN REDACTIE',
'info_redirection' => 'Omleiding',
'info_referencer_doc_distant' => 'Naar een document op internet verwijzen&nbsp;:',
'info_refuses' => 'Uw geweigerde artikels',
'info_reglage_ldap' => 'Opties : <b>Instellen van de LDAP invoer</b>',
'info_renvoi_article' => '<b>Doorsturen.</b> Dit artikel verwijst naar de pagina:',
'info_reserve_admin' => 'Alleen beheerders kunnen dit adres wijzigen.',
'info_restauration_sauvegarde' => 'Restauratie van de bescherming @archive@',
'info_restauration_sauvegarde_insert' => 'Integratie van @archive@ in de basis',
'info_restreindre_rubrique' => 'Beheer tot deze rubriek beperken :',
'info_resultat_recherche' => 'onderzoek resultaats:',
'info_rubriques' => 'Rubrieken',
'info_rubriques_02' => 'Rubrieken',
'info_rubriques_liees_mot' => 'Rubrieken gekoppeld aan dit trefwoord',
'info_rubriques_trouvees' => 'Rubrieken vondeling',
'info_rubriques_trouvees_dans_texte' => 'Rubrieken vondeling (in tekst)',
'info_sans_titre' => 'Zonder titel',
'info_sauvegarde' => 'Backup',
'info_sauvegarde_articles' => 'Artikel redden',
'info_sauvegarde_articles_sites_ref' => 'Artikels van de referentiesites bewaren',
'info_sauvegarde_auteurs' => 'Backup de auteurs',
'info_sauvegarde_breves' => 'Backup de berichten',
'info_sauvegarde_documents' => 'Backup de dokumenten',
'info_sauvegarde_echouee' => 'Indien het maken van de reserverkopie mislukt is (&laquo;Maximum execution time exceeded&raquo;),',
'info_sauvegarde_forums' => 'Backup de forums',
'info_sauvegarde_groupe_mots' => 'Groepen trefwoorden bewaren',
'info_sauvegarde_messages' => 'Bewaar de berichten',
'info_sauvegarde_mots_cles' => 'Trefwoorden bewaren',
'info_sauvegarde_petitions' => 'Petities bewaren',
'info_sauvegarde_refers' => 'Backup de referers',
'info_sauvegarde_reussi_01' => 'Backup succes.',
'info_sauvegarde_reussi_02' => 'De databank werd bewaard in @archive@. Je kan ',
'info_sauvegarde_reussi_03' => 'terugkeren naar het beheer',
'info_sauvegarde_reussi_04' => 'op uw website.',
'info_sauvegarde_rubrique_reussi' => 'De tabels van de rubriek @titre@ werden in @archive@ beschermd. U kunt',
'info_sauvegarde_rubriques' => 'Backup rubrieken',
'info_sauvegarde_signatures' => 'De namen van de petitie bewaren',
'info_sauvegarde_sites_references' => 'De gekoppelde sites opslaan',
'info_sauvegarde_type_documents' => 'Types documenten opslaan',
'info_sauvegarde_visites' => 'Backup de bezoeken',
'info_selection_chemin_acces' => '<b>Selecteer</b> hierna de toegangswijze tot het jaarboek:',
'info_selection_un_seul_mot_cle' => 'Men kan slechts <b>&eacute;&eacute;n enkel trefwoord</b> tegelijk kiezen uit deze groep.',
'info_signatures' => 'namen',
'info_site' => 'Site',
'info_site_2' => 'site :',
'info_site_min' => 'site',
'info_site_propose' => 'Site voorgesteld op :',
'info_site_reference_2' => 'Gekoppelde site',
'info_site_syndique' => 'Gesyndiceerde site...',
'info_site_valider' => 'Goed te keuren sites',
'info_site_web' => 'WEBSITE :',
'info_sites' => 'sites',
'info_sites_lies_mot' => 'Referentiesites gekoppeld aan het trefwoord ',
'info_sites_proxy' => 'Een proxy gebruiken',
'info_sites_refuses' => 'De geweigerde websites',
'info_sites_trouves' => 'Sites zocht',
'info_sites_trouves_dans_texte' => 'Gevonden sites (in de tekst)',
'info_sous_titre' => 'Ondertitel:',
'info_statut_administrateur' => 'Administrator',
'info_statut_auteur' => 'Statuut van deze auteur&nbsp;:',
'info_statut_auteur_a_confirmer' => 'Inschrijving bevestigen',
'info_statut_auteur_autre' => 'Andere status&nbsp;:',
'info_statut_efface' => 'Uitgewist',
'info_statut_redacteur' => 'Redacteur',
'info_statut_site_1' => 'Deze site is:',
'info_statut_site_2' => 'Publicerd',
'info_statut_site_3' => 'Voorgesteld',
'info_statut_site_4' => 'Naar de vuilnisbak',
'info_statut_utilisateurs_1' => 'Standaardstatus voor de ingevoerde gebruikers',
'info_statut_utilisateurs_2' => 'Kies de status die de personen uit het LDAP-adressenboek toebediend krijgen als ze de eerste keer inloggen. Nadien kan je deze status van elke auteur altijd &eacute;&eacute;n per &eacute;&eacute;n wijzgen.',
'info_suivi_activite' => 'Vervolg van de editoriale activiteit',
'info_supprimer_mot' => 'dit&nbsp;woord&nbsp;verwijderen',
'info_surtitre' => 'Opschrift',
'info_syndication_integrale_1' => 'Uw site stelt syndicatiebestanden voor (zie &laquo;&nbsp;<a href="@url@">@titre@</a>&nbsp;&raquo;).',
'info_syndication_integrale_2' => 'Wil u integrale artikels doorgeven of enkel een samenvatting van enkele honderden karakters doorgeven&nbsp;?',
'info_table_prefix' => 'U kunt het voorvoegsel van de naam van de tabel van gegevens (dit is absoluut noodzakelijk wanneer men verschillende sites in dezelfde database wil sites) wijzigen. Dit voorvoegsel schrijft zich in kleine letters, niet geaccentueerd, en zonder ruimte.',
'info_taille_maximale_images' => 'SPIP zal de maximumomvang van de beelden testen die hij kan behandelen (in miljoenen pixels). <br/> zullen de grotere beelden niet verminderd zijn.',
'info_taille_maximale_vignette' => 'Maximale grootte van de mini-afbeeldingen gemaakt door het systeem:',
'info_terminer_installation' => 'Je kan de standaardinstallatieprocedure nu be&euml;indigen.',
'info_texte' => 'Tekst',
'info_texte_explicatif' => 'Uitleg',
'info_texte_long' => '(de tekst is lang: hij zal bijgevolg in verschillende delen verschijnen die opnieuw bij elkaar worden gezet na goedkeuring van de tekst.)',
'info_texte_message' => 'Tekst van je bericht:',
'info_texte_message_02' => 'Tekst van het bericht',
'info_titre' => 'Titel:',
'info_titre_mot_cle' => 'Name of titel voor slautelwoord',
'info_total' => 'totaal :',
'info_tous_articles_en_redaction' => 'Alle artikels in redactie',
'info_tous_articles_presents' => 'Alle gepubliceerde artikels van deze rubriek',
'info_tous_articles_refuses' => 'Tous les articles refus&eacute;s', # NEW
'info_tous_les' => 'alle :',
'info_tous_redacteurs' => 'Berichten voor alle redacteurs',
'info_tout_site' => 'Volledige site',
'info_tout_site2' => 'Het artikel werd niet naar deze taal vertaald.',
'info_tout_site3' => 'Het artikel werd naar deze taal vertaald maar aan het bronartikel werden wijzigingen aangebracht. De vertaling dient geactualiseerd te worden.',
'info_tout_site4' => 'Het artikel is vertaald naar deze taal en de vertaling is geactualiseerd.',
'info_tout_site5' => 'Origineel artikel.',
'info_tout_site6' => '<b>Opgelet&nbsp;:</b> enkel de originele artikels worden getoond.
Vertalingen worden gelinkt aan het origineel,
een kleur geeft hun status aan&nbsp;:',
'info_travail_colaboratif' => 'Samenwerking voor de artikels',
'info_un_article' => 'een Artikel, ',
'info_un_mot' => 'Een enkel trefwoord',
'info_un_site' => 'een Website, ',
'info_une_breve' => 'een bericht',
'info_une_rubrique' => 'een Rubriek, ',
'info_une_rubrique_02' => '1 Rubriek',
'info_url' => 'URL&nbsp;:',
'info_url_site' => 'WEBSITE URL&nbsp;:',
'info_urlref' => 'Adres van de koppeling&nbsp;:',
'info_utilisation_spip' => 'Je kan het publicatiesysteem nu gebruiken...',
'info_visites_par_mois' => 'Tonen per maand :',
'info_visites_plus_populaires' => 'Toon de bezoeken voor <b>de meest populaire artikels</b> en voor <b>de laatst gepubliceerde artikels:</b>',
'info_visiteur_1' => 'Bezoeker',
'info_visiteur_2' => 'van de publieke site',
'info_visiteurs' => 'Bezoekers',
'info_visiteurs_02' => 'Bezoekers van de publieke site',
'install_adresse_base_hebergeur' => '<modif>Adres van de database die door leverancier wordt toegekend',
'install_base_ok' => 'De basis @base@ werd erkend',
'install_echec_annonce' => 'De installatie zal wellicht mislukken of leiden tot een niet-werkende site...',
'install_extension_mbstring' => 'SPIP functioneert niet met &nbsp;:',
'install_extension_php_obligatoire' => 'SPIP heeft de php extensie nodig&nbsp;:',
'install_login_base_hebergeur' => 'Login van aansluiten die door leverancier wordt toegekend',
'install_nom_base_hebergeur' => 'De naam van de basis die door de leverancier&nbsp; wordt toegekend:',
'install_pas_table' => 'Basis momenteel zonder tabels',
'install_pass_base_hebergeur' => 'Wachtwoord van aansluiten dat door leverancier wordt toegekend',
'install_php_version' => 'PHP versie @version@ onvoldoende (minimum = @minimum@)',
'install_select_langue' => 'Kies een taal en klik vervolgens op de knop  &laquo;volgende&raquo; om de installatie te beginnen.',
'install_select_type_db' => 'Het basissoort gegevens aangeven:',
'install_select_type_mysql' => 'MySQL',
'install_select_type_pg' => 'PostgreSQL', # NEW
'install_select_type_sqlite2' => 'SQLite 2',
'install_select_type_sqlite3' => 'SQLite 3',
'install_serveur_hebergeur' => 'Basisserver van gegevens die door de leverancier wordt toegekend',
'install_table_prefix_hebergeur' => 'Het voorvoegsel van tafel dat door de leverancier wordt toegekend:',
'install_tables_base' => 'Tabelen van de basis',
'install_types_db_connus' => 'SPIP weten gebruiken <b>MySQL</b> (het meest verbreid), <b>PostgreSQL</b> en <b>SQLite</b>.',
'install_types_db_connus_avertissement' => 'Aandacht&nbsp;: verschillende plugins werken slechts met MySQL',
'intem_redacteur' => 'redacteur',
'intitule_licence' => 'Licentie',
'item_accepter_inscriptions' => 'Inschrijvingen aanvaarden',
'item_activer_forum_administrateur' => 'Forum van beheerders activeren',
'item_activer_messages_avertissement' => 'Waarschuwingsberichten activeren',
'item_administrateur_2' => 'beheerder',
'item_afficher_calendrier' => 'Op de kalender tonen',
'item_ajout_mots_cles' => 'Gebruik van trefwoorden toestaan op de forums',
'item_autoriser_documents_joints' => 'Gebruik van bijlagen bij artikels toestaan',
'item_autoriser_documents_joints_rubriques' => 'Gebruik van bijlagen bij rubrieken toestaan',
'item_autoriser_selectionner_date_en_ligne' => 'Het mogelijk maken om de datum van elk document te wijzigen',
'item_autoriser_syndication_integrale' => 'Volledige artikels verspreiden via syndicatie',
'item_bloquer_liens_syndiques' => 'Gesyndiceerde koppelingen tegenhouden voor goedkeuring ',
'item_breve_refusee' => 'NEEN - Geweigerd nieuwsbericht',
'item_breve_validee' => 'JA - Goedgekeurd nieuwsbericht',
'item_choix_administrateurs' => 'de beheerders',
'item_choix_generation_miniature' => 'Automatisch aanmaken van verkleinde afbeeldingen.',
'item_choix_non_generation_miniature' => 'Geen verkleinde afbeeldingen aanmaken.',
'item_choix_redacteurs' => 'de redacteurs',
'item_choix_visiteurs' => 'bezoekers van de publieke site',
'item_compresseur' => 'De samendrukking activeren',
'item_config_forums_prive_global' => 'Het redacteuren forum activeren',
'item_config_forums_prive_objets' => 'Deze forums activeren',
'item_creer_fichiers_authent' => 'de .htpasswd bestanden aanmaken',
'item_desactiver_forum_administrateur' => 'Forum van de beheerders desactiveren',
'item_gerer_annuaire_site_web' => 'Een adresboek van de websites aanmaken',
'item_gerer_statistiques' => 'Statistieken aanmaken',
'item_limiter_recherche' => 'opzoeking beperken tot informatie van je eigen site',
'item_login' => 'Login',
'item_messagerie_agenda' => 'De besteldienst en de agenda activeren',
'item_mots_cles_association_articles' => 'Het artikels',
'item_mots_cles_association_breves' => 'de bericht',
'item_mots_cles_association_rubriques' => 'van de rubrieken',
'item_mots_cles_association_sites' => 'van de gesyndiceerde of gerefereerde sites.',
'item_non' => 'Nee',
'item_non_accepter_inscriptions' => 'Geen inschrijvingen aanvaarden',
'item_non_activer_messages_avertissement' => 'Geen waarschuwingsberichten',
'item_non_afficher_calendrier' => 'Niet tonen op de kalender',
'item_non_ajout_mots_cles' => 'Gebruik van trefwoorden in de forums niet toestaan',
'item_non_autoriser_documents_joints' => 'Bijlagen bij artikels niet toestaan',
'item_non_autoriser_documents_joints_rubriques' => 'Bijlagen bij rubrieken niet toestaan',
'item_non_autoriser_selectionner_date_en_ligne' => 'De datum van de documenten is die van hun toevoegsel op de plaats',
'item_non_autoriser_syndication_integrale' => 'Enkel een samenvatting verspreiden',
'item_non_bloquer_liens_syndiques' => 'Koppelingen komende van de syndicatie niet blokkeren',
'item_non_compresseur' => 'De samendrukking desactiveren',
'item_non_config_forums_prive_global' => 'Het forum van de redacteuren desactiveren',
'item_non_config_forums_prive_objets' => 'Deze forums desactiveren',
'item_non_creer_fichiers_authent' => 'Deze bestanden niet aanmaken',
'item_non_gerer_annuaire_site_web' => 'Adresboek van websites desactiveren',
'item_non_gerer_statistiques' => 'Geen statistieken aanmaken',
'item_non_limiter_recherche' => 'De zoekopdracht uitbreiden naar de inhoud van de gerefereerde sites',
'item_non_messagerie_agenda' => 'De besteldienst en de agenda desactiveren',
'item_non_publier_articles' => 'Artikels niet vrijgeven voor de vastgelegde datum van publicatie',
'item_non_utiliser_breves' => 'Geen gebruik maken van nieuwsberichten',
'item_non_utiliser_config_groupe_mots_cles' => 'Geavanceerde configuratie van groepen trefwoorden niet gebruiken',
'item_non_utiliser_moteur_recherche' => 'Zoekmachine niet gebruiken',
'item_non_utiliser_mots_cles' => 'Trefwoorden niet gebruiken',
'item_non_utiliser_syndication' => 'Automatische syndicatie niet gebruiken',
'item_nouvel_auteur' => 'Nieuwe auteur',
'item_nouvelle_breve' => 'Nieuw bericht',
'item_nouvelle_rubrique' => 'Nieuw rubriek',
'item_oui' => 'Ja',
'item_publier_articles' => 'Artikels publiceren, welke ook hun publicatiedatum is.',
'item_reponse_article' => 'Antwoord von Artikel',
'item_utiliser_breves' => 'Nieuwsberichten gebruiken',
'item_utiliser_config_groupe_mots_cles' => 'Geavanceerde configuratie van groepen trefwoorden gebruiken',
'item_utiliser_moteur_recherche' => 'De zoekmachine gebruiken',
'item_utiliser_mots_cles' => 'Trefwoorden gebruiken',
'item_utiliser_syndication' => 'Automatische syndicatie gebruiken',
'item_visiteur' => 'bezoeker',

// J
'jour_non_connu_nc' => 'onbekend',

// L
'ldap_correspondance' => 'erfenis van het veld @champ@',
'ldap_correspondance_1' => 'Erfenis van de velden LDAP',
'ldap_correspondance_2' => 'Voor elk volgend SPIP veld, de naam van het overeenkomstige veld LDAP aangeven. Leegte laten om niet het te vullen, door ruimtes of komma\'s te scheiden om verschillende LDAP velden te proberen.',
'lien_ajout_destinataire' => 'Voeg deze bestemmeling toe',
'lien_ajouter_auteur' => 'Voeg deze auteur toe',
'lien_ajouter_participant' => 'Voeg nieuwe deelnemer toe',
'lien_email' => 'e-mail',
'lien_forum_public' => 'Beheer het publieke forum van dit artikel',
'lien_mise_a_jour_syndication' => 'Update nu',
'lien_nom_site' => 'WEBSITENAME:',
'lien_nouvelle_recuperation' => 'Probeer de gegevens opnieuw te vinden',
'lien_reponse_article' => 'Beantwoord dit artikel',
'lien_reponse_breve' => 'Beantwoord dit nieuwsbericht',
'lien_reponse_breve_2' => 'Beantwoord dit nieuwsbericht',
'lien_reponse_rubrique' => 'Beantwoord deze rubriek',
'lien_reponse_site_reference' => 'Antwoord op gekoppelde site :',
'lien_retirer_auteur' => 'Auteur verwijderen',
'lien_retrait_particpant' => 'Deelnemer verwijderen',
'lien_site' => 'Site',
'lien_supprimer_rubrique' => 'Rubriek verwijderen',
'lien_tout_deplier' => 'Alles uitvouwen',
'lien_tout_replier' => 'Alles invouwen',
'lien_tout_supprimer' => 'Alles afschaffen',
'lien_trier_nom' => 'Sorteer op naam',
'lien_trier_nombre_articles' => 'Sorteer op aantal artikels',
'lien_trier_statut' => 'Sorteer op status',
'lien_voir_en_ligne' => 'ONLINE BEKIJKEN:',
'logo_article' => 'LOGO VAN HET ARTIKEL',
'logo_auteur' => 'LOGO VAN DE AUTEUR',
'logo_breve' => 'LOGO VAN HET NIEUWSBERICHT',
'logo_mot_cle' => 'LOGO VAN HET TREFWOORD',
'logo_rubrique' => 'LOGO VAN DE RUBRIEK',
'logo_site' => 'LOGO VAN DE WEBSITE',
'logo_standard_rubrique' => 'STANDAARDLOGO VOOR RUBRIEKEN',
'logo_survol' => 'ZWEVEND LOGO',

// M
'menu_aide_installation_choix_base' => 'Databank kiezen',
'module_fichier_langue' => 'Taalbestand',
'module_raccourci' => 'Snelkoppeling',
'module_texte_affiche' => 'Weergegeven tekst',
'module_texte_explicatif' => 'Je kan de volgende snelkoppelingen invoegen in de sjablonen van je publieke site. Ze worden automatisch vertaald in de verschillende talen waarvoor een taalbestand is aangemaakt.',
'module_texte_traduction' => 'Het taalbestand &laquo;&nbsp;@module@&nbsp;&raquo; is beschikbaar in het&nbsp;:',
'mois_non_connu' => 'Onbekend',

// N
'nouvelle_version_spip' => 'La version @version@ de SPIP est disponible', # NEW

// O
'onglet_contenu' => 'Inhoud',
'onglet_declarer_une_autre_base' => 'Een andere basis verklaren',
'onglet_discuter' => 'Discussi&euml;ren',
'onglet_documents' => 'Documenten',
'onglet_interactivite' => 'Interactiviteit',
'onglet_proprietes' => 'Eigendommen',
'onglet_repartition_actuelle' => 'nu',
'onglet_sous_rubriques' => 'Onder-rubrieken',

// P
'page_pas_proxy' => 'Deze bladzijde moet niet via proxy gaan',
'pas_de_proxy_pour' => 'Desnoods geeft de machines of gebieden aan waarvoor dit proxy niet moet van toepassing zijn (bijvoorbeeld&nbsp;: @exemple@)',
'plugin_charge_paquet' => 'Lading van het pak @name@',
'plugin_charger' => 'T&#233;l&#233;charger', # NEW
'plugin_erreur_charger' => 'fout&nbsp;: onmogelijk om @zip@ te laden',
'plugin_erreur_droit1' => 'De lijst <code>@dest@</code> is niet toegankelijk in schrift.',
'plugin_erreur_droit2' => 'Gelieve de rechten op deze lijst (en het eventueel te cre&euml;ren) controleren, of de bestanden door FTP plaatsen.',
'plugin_erreur_zip' => 'de mislukking pclzip&nbsp;: fout @status@',
'plugin_etat_developpement' => 'in ontwikkeling',
'plugin_etat_experimental' => 'experimenteel',
'plugin_etat_stable' => 'stabiel',
'plugin_etat_test' => 'in test',
'plugin_impossible_activer' => 'Onmogelijk om plugin @plugin@ te activeren',
'plugin_info_automatique1' => 'Als u tot de automatische installatie van plugins wilt machtiging verlenen, zal willen&nbsp;:',
'plugin_info_automatique1_lib' => 'Si vous souhaitez autoriser l\'installation automatique de cette librairie, veuillez&nbsp;:', # NEW
'plugin_info_automatique2' => 'een lijst <code>@rep@</code> cre&euml;ren&nbsp;;',
'plugin_info_automatique3' => 'controleren dat de server wordt gemachtigd om in deze lijst te schrijven.',
'plugin_info_automatique_creer' => 'om aan de wortel van de plaats te cre&euml;ren.',
'plugin_info_automatique_exemples' => 'voorbeelden&nbsp;:',
'plugin_info_automatique_ftp' => 'U kunt een plugins, door FTP, in de lijst <tt>@rep@</tt> plaatsen',
'plugin_info_automatique_lib' => 'Sommige plugins vragen eveneens om bestanden in de lijst <code>lib/</code> te kunnen downloaden, om eventueel aan de wortel van de plaats te cre&euml;ren.',
'plugin_info_automatique_liste' => 'Uw lijsten van plugins&nbsp;:',
'plugin_info_automatique_liste_officielle' => 'plugins ambtenaren',
'plugin_info_automatique_liste_update' => 'De lijsten bijwerken',
'plugin_info_automatique_ou' => 'om...',
'plugin_info_automatique_select' => 'Selecteert hieronder een plugin&nbsp;: SPIP zal het downloaden en zal in de lijst <code>@rep@</code>&nbsp; het plaatsen; als dit plugin reeds bestaat, zal hij bijgewerkt worden.',
'plugin_info_extension_1' => 'Les extensions ci-dessous sont charg&#233;es et activ&#233;es dans le r&#233;pertoire @extensions@.', # NEW
'plugin_info_extension_2' => 'Elles ne sont pas d&#233;sactivables.', # NEW
'plugin_info_telecharger' => 'om sinds @url@ te downloaden en om te plaatsen in @rep@',
'plugin_librairies_installees' => 'Geplaatste boekhandels',
'plugin_necessite_lib' => 'Dit plugin vereist de boekhandel @lib@',
'plugin_necessite_plugin' => 'Vereist plugin @plugin@ in versie minimale @version@.',
'plugin_necessite_spip' => 'Vereist SPIP in versie minimale @version@.',
'plugin_source' => 'oorsprong:&nbsp;',
'plugin_titre_automatique' => 'Automatische installatie',
'plugin_titre_automatique_ajouter' => 'Een plugins toevoegen',
'plugin_titre_installation' => 'Installation du plugin @plugin@', # NEW
'plugin_zip_active' => 'Gaat door om het te activeren',
'plugin_zip_adresse' => 'geeft hieronder het adres van een bestand zip van te downloaden plugin, of nog het adres van een lijst van plugins aan.',
'plugin_zip_adresse_champ' => 'Adres van plugin of de lijst&nbsp;',
'plugin_zip_content' => 'Hij bevat de volgende bestanden (@taille@), <br/>leningen die in de lijst <code>@rep@</code> moeten geplaatst worden',
'plugin_zip_installe_finie' => 'Het bestand @zip@ is unzip en werd geplaatst.',
'plugin_zip_installe_rep_finie' => 'Het bestand @zip@ is unzip en werd in de lijst @rep@ geplaatst',
'plugin_zip_installer' => 'U kunt nu het plaatsen.',
'plugin_zip_telecharge' => 'Het bestand @zip@ werd geladen',
'plugins_actif_aucun' => 'Aucun plugin activ&#233;.', # NEW
'plugins_actif_un' => 'Un plugin activ&#233;.', # NEW
'plugins_actifs' => '@count@ plugins activeren.',
'plugins_actifs_liste' => 'Plugins actifs', # NEW
'plugins_compte' => '@count@ plugins',
'plugins_disponible_un' => 'Un plugin disponible.', # NEW
'plugins_disponibles' => '@count@ plugins beschikbaar.',
'plugins_erreur' => 'De fout in plugins: @plugins@',
'plugins_liste' => 'Lijst van plugins',
'plugins_liste_extensions' => 'Extensions', # NEW
'plugins_recents' => 'Plugins r&eacute;cents.', # NEW
'plugins_vue_hierarchie' => 'Hi&euml;rarchie',
'plugins_vue_liste' => 'Lijst',
'protocole_ldap' => 'De versie van het protocol :',

// R
'repertoire_plugins' => 'Map&nbsp;:',

// S
'sans_heure' => 'zonder huur',
'sauvegarde_fusionner' => 'De huidige basis en de bescherming fusioneren',
'sauvegarde_fusionner_depublier' => 'De gefusioneerde onderwerpen depubliceren',
'sauvegarde_url_origine' => 'Eventueel URL van de site van oorsprong:',
'statut_admin_restreint' => '(beperkte toegang)',
'syndic_choix_moderation' => 'Wat te doen met volgende links afkomstig van deze site&nbsp;?',
'syndic_choix_oublier' => 'Wat te doen met links die niet langer voorkomen in het bestand voor syndicatie&nbsp;?',
'syndic_choix_resume' => 'Sommige sites verspreiden de volledige tekst van een artikel. Indien deze beschikbaar is, wil je hem dan ontvangen&nbsp;:',
'syndic_lien_obsolete' => 'obsoleet link',
'syndic_option_miroir' => 'automatisch blokkeren',
'syndic_option_oubli' => 'uitwissen (na @mois@&nbsp;maanden)',
'syndic_option_resume_non' => 'de volledige inhoud van de artikels (in HTML formaat)',
'syndic_option_resume_oui' => 'een eenvoudige samenvattig (tekstformaat)',
'syndic_options' => 'Syndicatie opties&nbsp;:',

// T
'taille_cache_image' => 'De beelden door SPIP automatisch aangemaakt (icoontjes van documenten, grafisch weergegeven titels, wiskundige functies in TeX formaat...) nemen in de map @dir@ een totale plaats in van  @taille@.',
'taille_cache_infinie' => 'De site voorziet geen beperking in de grootte van de buffermap.',
'taille_cache_maxi' => 'SPIP probeert de omvang van de buffermap van de site te beperken tot ongeveer <b>@octets@</b> gegevens.',
'taille_cache_octets' => 'De grootte van de buffer bedraagt momenteel @octets@.',
'taille_cache_vide' => 'De buffer is leeg.',
'taille_repertoire_cache' => 'Grootte van het bufferbestand',
'text_article_propose_publication' => 'Artikel voorgesteld voor de publicatie.',
'text_article_propose_publication_forum' => 'Aarzelt niet om uw advies te geven dank zij het forum dat aan dit artikel wordt vastgemaakt (beneden van bladzijde).',
'texte_acces_ldap_anonyme_1' => 'Sommige LDAP-servers aanvaarden geen anonieme toegang. In zo\'n geval dien je &eacute;&eacute;n loginnaam op te geven om vervolgens informatie in het adressenboek te zoeken. In de meeste gevallen kan je de volgende velden echter leeg laten.',
'texte_admin_effacer_01' => 'Met dit commando vernietig je de  <i>volledige</i> inhoud van de databank,
inbegrepen <i>alle</i> toegangsrechten voor redacteurs en beheerders. Nadat je dit uitgevoerd hebt, dien je de herinstallatie van SPIP te starten om een volledig nieuwe database aan te maken en toegangsrechten voor een eerste beheerder.',
'texte_admin_effacer_stats' => 'Deze bestelling wist alle gegevens in verband met de statistieken van bezoek van de plaats uit, met inbegrip van de populariteit van de artikelen.',
'texte_admin_tech_01' => 'Deze optie laat je toe de inhoud van de databank te bewaren in een bestand dat bewaard zal worden in de map @dossier@. Vergeet ook niet de volledige map @img@ te bewaren. Zij bevat alle afbeeldingen en bijlagen bij de artikels en rubrieken.',
'texte_admin_tech_02' => 'Opgelet: deze bescherming zal SLECHTS in een plaats kunnen hersteld worden die onder dezelfde versie van SPIP wordt geplaatst. Men heeft dus vooral geen &laquo;&nbsp;nodig de basis&nbsp;&raquo; te legen door de bescherming te hopen opnieuw te installeren na een update… Raadpleegt <a href= " @spipnet@ " > de documentatie van SPIP </a>.',
'texte_admin_tech_03' => 'Je kan de reservekopie ook als een gecomprimeerd bestand opslaan, dit om de overzettijd van de server naar je computer sterk in te korten en om schijfruimte te besparen.',
'texte_admin_tech_04' => 'Met het oog op fusie met een andere basis, kunt u de bescherming beperken tot de rubriek:',
'texte_adresse_annuaire_1' => '(Als de map is ge&iuml;nstalleerd is op dezelfde computer als je website, is het waarschijnlijk &laquo;localhost&raquo;.)',
'texte_ajout_auteur' => 'Deze auteuer is toegevoegd aan het artikel :',
'texte_annuaire_ldap_1' => 'Als je toegang hebt tot een LDAP-adresboek, kan je dit gebruiken om automatisch gebruikers in te voeren in SPIP.',
'texte_article_statut' => 'Dit artikel is:',
'texte_article_virtuel' => 'Virtual artikel',
'texte_article_virtuel_reference' => '<b>Virtueel artikel:</b> gekoppeld artikel in je SPIP site maar doorgestuurd naar een andere URL. Verwijder de URL om de doorverwijzing te stoppen.',
'texte_aucun_resultat_auteur' => 'Geen resultaat voor "@cherche_auteur@"',
'texte_auteur_messagerie' => 'Deze website kan een lijst met auteurs die op dat moment aangelogd zijn, tonen. Het is mogelijk om direkt berichten opsturen en ontvangen tussen de auteurs.  Je kan kiezen om niet in deze lijst te verschijnen (je wordt dan &laquo;&nbsp;onzichtbaar&nbsp;&raquo; voor de andere gebruikers).',
'texte_auteur_messagerie_1' => 'Deze site biedt de mogelijkheid om berichten uit te wisselen en forums op te starten voor private discussies tussen de deelnemers van de site. Je kan kiezen om niet deel te nemen aan deze uitwisseling van informatie.',
'texte_auteurs' => 'DE AUTEURS',
'texte_breves' => 'Berichten zijn korte en eenvoudige teksten die je toelaten nieuws snel online te brengen, een persbericht op te stellen, een evenementenkalender te maken, ...',
'texte_choix_base_1' => 'Kies je databank :',
'texte_choix_base_2' => 'De SQL server bevat meerdere databanken.',
'texte_choix_base_3' => '<b>Kies</b> hierna die die u door uw leverancier werd toegekend:',
'texte_choix_table_prefix' => 'Voorvoegsel van de tabelen&nbsp;:',
'texte_commande_vider_tables_indexation' => 'Gebruik dit commando als je de tabellen met indices wil leegmaken die door de
 zoekmachine van SPIP gebruikt worden. Zo kan je schijfruimte vrijmaken.',
'texte_comment_lire_tableau' => 'De plaats van het artikel,
 in de rangschikking volgens populariteit, is in de marge
 aangegeven; de populariteit(*) van het artikel en het
 aantal bezoeken sinds het het begin van de site staan in
 het vakje dat verschijnt als je met de muis over de
 titel van het artikel komt.

(*) de populariteit van een artikel is een schatting van
 het aantal bezoeken dat het artikel op een dag zal
 krijgen als huidige ritme van raadpleging wordt
 aangehouden.',
'texte_compacter_avertissement' => 'De aandacht om niet deze opties tijdens de ontwikkeling van uw site te activeren: de compact elementen verliezen elke leesbaarheid.',
'texte_compacter_script_css' => 'SPIP kan compact de javascript scripts en de CSS stijl bladen, om ze te registreren in statische bestanden; dat versnelt de display van de site.',
'texte_compresse_ou_non' => '(deze kan gecomprimeerd worden of niet)',
'texte_compresseur_page' => 'SPIP kan elke bladzijde automatisch samenpersen die hij naar
 bezoekers van de site verzendt. Dit regelen maakt het mogelijk om de drukke reep te optimaliseren (de
 site is sneller achter een verbinding aan gering debiet), maar
 vraagt meer macht aan de server.',
'texte_compte_element' => '@count@ element',
'texte_compte_elements' => '@count@ elements',
'texte_config_groupe_mots_cles' => 'Wilt u de geavanceerde configuratie van de sleutelwoorden activeren,
   door mede te delen bijvoorbeeld dat men een enig woord
 kan selecteren   per groep, dat een groep belangrijk is...&nbsp;?',
'texte_conflit_edition_correction' => 'Gelieve de verschillen tussen beide versies van de tekst&nbsp; hieronder te controleren; u kunt eveneens uw wijzigingen kopi&euml;ren, vervolgens opnieuw beginnen.',
'texte_connexion_mysql' => 'Raadpleegt de inlichtingen die door uw leverancier&nbsp; worden verstrekt: u moet er de basisserver van gegevens vinden die men voorstelt en uw persoonlijke identificaties om u erop aan te sluiten.',
'texte_contenu_article' => '(Inhoud van het artikel in enkele woorden.)',
'texte_contenu_articles' => 'Naargelang de opmaak van je website kan je beslissen sommige elementen van artikels
 wel of niet te gebruiken.
 Duidt hieronder op de lijst de elementen aan die je wil gebruiken.',
'texte_crash_base' => 'Als je database gecrashed is,
  kan je een automatisch herstel proberen.',
'texte_creer_rubrique' => 'Alvorens artikelen te kunnen schrijven, <br/> moet u een rubriek cre&euml;ren.',
'texte_date_creation_article' => 'DATUM VAN AANMAKEN VAN HET ARTIKEL:',
'texte_date_publication_anterieure' => 'Datum van eerdere redactie&nbsp;:',
'texte_date_publication_anterieure_nonaffichee' => 'Verberg de datum van eerdere redactie.',
'texte_date_publication_article' => 'DATUM VAN ONLINE PUBLICATIE&nbsp;:',
'texte_descriptif_petition' => 'Beschrijving van de petitie.',
'texte_descriptif_rapide' => 'Korte beschrijving.',
'texte_documents_joints' => 'Je kan het toevoegen van documenten (teksten, afbeeldingen, multimedia, ...) bij artikels of rubrieken toelaten. De bijgevoegde bestanden 
kunnen vervolgens gekoppeld worden in het 
artikel of afzonderlijk getoond worden.', # MODIF
'texte_documents_joints_2' => 'Deze instelling verhindert de directe opname van beelden in artikels niet.',
'texte_effacer_base' => 'Verwijder de SPIP databank',
'texte_effacer_donnees_indexation' => 'Verwijder de ge&iuml;ndexeerde gegevens',
'texte_effacer_statistiques' => 'De statistieken uitwissen',
'texte_en_cours_validation' => 'De artikelen en berichten hieronder worden aan de publicatie voorgesteld.',
'texte_en_cours_validation_forum' => 'Aarzelt niet om uw advies te geven dank zij de forums die hun worden vastgemaakt.',
'texte_enrichir_mise_a_jour' => 'De opmaak van een tekst kan gebeuren met behulp van de zogeheten &laquo;typografische snelkoppelingen&raquo;.',
'texte_fichier_authent' => '<b>SPIP moet hij de speciale  <tt>.htpasswd</tt>
  en <tt>.htpasswd-admin</tt> bestanden aanmaken in de map @dossier@ ?</b><p>
 Deze bestanden zijn nuttig om de toegang tot andere delen
 van je website (zoals een extern programma voor
 statistieken, bijvoorbeeld) te beperken voor de auteurs en
 beheerders.</p><p>
Als u geen nut ervan hebt, kunt u deze keuze
 laten  aan zijn waarde per gebrek (niet een oprichting
  bestanden).</p>', # MODIF
'texte_informations_personnelles_1' => 'Nu zal het systeem een persoonlijke toegang tot de site voor u cre&euml;ren.',
'texte_informations_personnelles_2' => '(Nota : als het herinstallatie betreft,  en je toegangscode blijkt nog steeds te werken, kan je',
'texte_introductif_article' => '(Inleidende tekst op het artikel.)',
'texte_jeu_caractere' => 'Het is aan te raden op je site het universele alfabet (<tt>utf-8</tt>) te gebruiken&nbsp;:dit laat de weergave van teksten toe in alle talen en stelt geen compatibilieitsprobleemet de recente bladerprogramma\'s.',
'texte_jeu_caractere_2' => 'Opgelet : deze instelling zal teksten die reeds werden ingevoerd in de gegevensbank niet omzetten.',
'texte_jeu_caractere_3' => 'Je site is momenteel ge&iuml;nstalleerd in deze tekenset&nbsp;:',
'texte_jeu_caractere_4' => 'Indien dit niet overeenkomt met je werkelijke gegevens (bvb bij het terugzetten van je gegevensbank), of als je <em>deze site opstart</em> en met een andere tekenset van start wil gaan, gelieve deze dan hieronder aan te duiden&nbsp;:',
'texte_jeu_caractere_conversion' => 'Noot&nbsp;: je kan beslissen eens en voorgoed al je teksten van je site (artikels, berichten, forums, enz.) naar het <tt>utf-8</tt> alfabet om te zetten, door naar <a href="@url@">de pgaina voor omzetting naar utf-8</a> te gaan.',
'texte_lien_hypertexte' => '(Als je artikel handelt over iets dat op het web is gepubliceerd, of naar een internetpagina verwijst met meer informatie, gelieve dan hier de titel en de URL van deze pagina op te geven.)',
'texte_liens_sites_syndiques' => 'Koppelingen komende van gesyndiceerde sites kunnen op voorhand
   geblokkeerd worden; de instelling
   hieronder zegt wat de standaardinstelling is
   voor gesyndiceerde sites als ze aangemaakt worden.
   Het is vervolgens perfect mogelijk om elke koppeling
   individueel te ontgrendelen, of om per site
   te kiezen of je koppelingen wil blokkeren of niet.',
'texte_login_ldap_1' => '(Leeg laten voor een anonieme login, of een volledig pad invullen, bijvoorbeeld &laquo;<tt>uid=janssen, ou=users, dc=mijn-domein, dc=com</tt>&raquo;.)',
'texte_login_precaution' => 'Opgelet! Met deze login ben je momenteel aangemeld.
 Gebruik dit formulier met de nodige voorzichtigheid...',
'texte_message_edit' => 'Opgelet: dit bericht kan door elke beheerder van de site gewijzigd worden en is zichtbaar voor elke redacteur. Maak enkel gebruik van deze aankondigingen om belangrijk nieuws in verband met de site kenbaar te maken.',
'texte_messagerie_agenda' => 'Een besteldienst laat de redacteuren van de site toe om tussen hen direct in de particuliere ruimte van de plaats mee te delen. Zij wordt verenigd met een agenda.',
'texte_messages_publics' => 'Publieke berichten van dit artikel :',
'texte_mise_a_niveau_base_1' => 'Je hebt zonet de SPIP bestanden vernieuwd. Nu dien je
 eveneens de databank te updaten.',
'texte_modifier_article' => 'Wijzigen artikel:',
'texte_moteur_recherche_active' => '<b>De zoekmotor is geactiveerd.</b> Voer deze taak uit als je een snelle herindexatie wil doorvoeren (na het terugzetten van een reservekopie bijvoorbeeld). Documenten die via de normale weg worden gewijzigd (vanaf de SPIP interface) worden automatisch geherindexeerd: deze taak is dus enkel nuttig in uitzonderlijke omstandigheden.',
'texte_moteur_recherche_non_active' => 'De zoekmachine is niet geactiveerd.',
'texte_mots_cles' => 'Met behulp van trefwoorden kan je thematische verbanden leggen tussen je artikels,
 onafhankelijk van hun plaats in de rubrieken. Zo kan je
 de navigatie op je site verbeteren maar ook de weergave
 van artikels aanpassen aan de inhoud.',
'texte_mots_cles_dans_forum' => 'Wilt u het gebruik van sleutelwoorden geselecteren door de bezoekers in de forums van de openbare site toelaten? (Aandacht&nbsp;: deze keuze is betrekkelijk ingewikkeld juist te gebruiken.)',
'texte_multilinguisme' => 'Als je graag artikels in verschillende talen zou willen beheren, met een complexe navigatie, kan je een taalkeuzemenu toevoegen bij de artikels en/of de rubrieken, i.f.v de organisatie van je site.',
'texte_multilinguisme_trad' => 'Je kan eveneens een systeem in werking stellen voor het beheer van koppelingen tussen de verschillende versies van een artikel.',
'texte_non_compresse' => '<i>niet gecomprimeerd</i> (de server ondersteunt deze functionaliteit niet)',
'texte_non_fonction_referencement' => 'Je kan kiezen om deze automatische functie uit te schakelen en zelf aangeven welke elementen je wil opnemen voor deze site.',
'texte_nouveau_message' => 'Nieuw bericht',
'texte_nouveau_mot' => 'Nieuw trefwoord',
'texte_nouvelle_version_spip_1' => 'Je hebt een nieuwe versie van SPIP ge&iuml;nstalleerd.',
'texte_nouvelle_version_spip_2' => 'Deze nieuwe SPIP-versie vereist een  grondiger update dan gewoonlijk. Als je webmaster bent van deze site, verwijder dan het bestand @connect@ en herneem de installatie om de verbindingsgegevens met de databank te vernieuwen.<p> (NB.&nbsp;: als je je verbindingsgegevens niet meer kent, kan je best eerst een blik werpen op het bestand @connect@ alvorens het te verwijderen...)</p>', # MODIF
'texte_operation_echec' => 'Ga terug naar de vorige pagina, selecteer een andere gegevensbank of maak een nieuwe aan. Kijk nog eens alle gegevens na die je van je provider hebt ontvangen.',
'texte_plus_trois_car' => 'meer dan 3 karakters',
'texte_plusieurs_articles' => 'Meerdere auteurs gevonden voor "@cherche_auteur@":',
'texte_port_annuaire' => '(De opgegeven standaardwaarde is meestal de juiste.)',
'texte_presente_plugin' => 'Deze pagina toont de lijst van beschikbare plugins op deze site. Je kan de nodige plugins activeren door het overeenkomstige vakje aan te kruisen.',
'texte_proposer_publication' => 'Wanneer uw artikel wordt be&euml;indigd, <br /> kunt u zijn publicatie voorstellen.',
'texte_proxy' => 'In bepaalde gevallen (intranet, beschermde netwerken), zijn de verwijderde plaatsen (SPIP documentatie , georganiseerde plaatsen, enz.) toegankelijk slechts door een <i>proxy HTTP</i>. Eventueel geeft hieronder zijn adres aan, onder de vorm @proxy_in_actie@. Over het algemeen zult u dit lege hokje laten.',
'texte_publication_articles_post_dates' => 'Hoe dient SPIP zich op te stellen ten opzichte van artikels waarvan de
  publicatiedatum is vastgelegd op een
  toekomstige datum?',
'texte_rappel_selection_champs' => '[Vergeet niet de juiste keuze te maken voor dit veld.]',
'texte_recalcul_page' => 'Als je enkel
 &eacute;&eacute;n pagina wil vernieuwen, doe dit dan op de publieke site en gebruik de knop  &laquo; vernieuwen &raquo;.',
'texte_recapitiule_liste_documents' => 'Deze pagina herneemt de lijst met documenten die je bij de rubrieken hebt geplaatst. Om de informatie van een document te wijzigen, volg je de link naar de pagina van de rubriek.',
'texte_recuperer_base' => 'De databank herstellen',
'texte_reference_mais_redirige' => 'Gekoppeld artikel in je SPIP site, maar doorgestuurd naar een andere URL.',
'texte_referencement_automatique' => '..<b>Geautomatiseerde koppelen van een site</b><br />U kunt een website snel verwijzen door het verlangde naar URL adres, of het adres van zijn bestand van syndication hieronder aan te geven. SPIP zal de informatie automatisch terugkrijgen betreffende deze plaats (titel, beschrijving...).',
'texte_referencement_automatique_verifier' => 'Gelieve de inlichtingen te controleren die per <tt>@url@</tt> worden verstrekt, alvorens te registreren.',
'texte_requetes_echouent' => 'b>Wanneer SQL verbindingen systematisch en zonder
 aanwijsbare redenen mislukken is het mogelijk dat het
 probleem bij de databank ligt. </b><p>
 SQL kan zelf een hersteloperatie uitvoeren op de
 tabellen in de databank die mogelijk beschadigd kunnen
 zijn. Je kan hier zo\'n hersteloperatie proberen. Als dit
 mislukt, kopieer dan het foutbericht wat aanwijzingen
 zal bevatten over de aard van het probleem...
 Is het probleem niet opgelost, wend je dan tot je
 hostingprovider.</p>', # MODIF
'texte_restaurer_base' => 'De inhoud van de reservekopie van de databank terugzetten',
'texte_restaurer_sauvegarde' => 'Deze optie laat je toe een eerder genomen reservekopie van de databank
 terug te plaatsen. Hiertoe dien je het bestand met de reservekopie
 te plaatsen in de map @dossier@.
 Wees voorzichtig met het gebruik van deze optie: <b>alle wijzigingen, eventuele verliezen, zijn
  onomkeerbaar.</b>',
'texte_sauvegarde' => 'Een reservekopie maken van de inhoud van de databank',
'texte_sauvegarde_base' => 'Reservekopie maken van de databank',
'texte_sauvegarde_compressee' => 'De reservekopie zal gemaakt worden in het niet-gecomprimeerde bestand @fichier@.',
'texte_selection_langue_principale' => 'Hieronder kan je de &laquo;basistaal&raquo; van de site kiezen. Deze keuze verplicht je - gelukkig! - niet om artikels in deze taal te schrijven maar laat wel toe om het volgende te bepalen:
 <ul><li> het standaardformaat van de data op de publieke site;</li>
 <li> de aard van de typografische motor die SPIP dient te gebruiken om teksten te tonen;</li>
 <li> de taal die gebruikt moet worden op de formulieren van de publieke site;</li>
 <li> de taal die standaard wordt voorgesteld in het private gedeelte.</li></ul>',
'texte_signification' => 'De donkere balkjes stellen alle samengetelde bezoeken weer (totaal van alle subrubrieken), de lichte balkjes het aantal bezoeken voor elke rubriek.',
'texte_sous_titre' => 'Ondertitel',
'texte_statistiques_visites' => '(donkere balkjes :  zondag / donkere lijn : evolutie van het gemiddelde)',
'texte_statut_attente_validation' => 'wachten op goedkeuring',
'texte_statut_publies' => 'online geplaatst',
'texte_statut_refuses' => 'geweigerd',
'texte_suppression_fichiers' => 'Gebruik dit commando om alle bestanden uit de  buffer (cache) te verwijderen.
Dit kan handig zijn als je veel pagina\'s hebt gewijzigd, de layout of de structuur van de site hebt veranderd.
 De nieuwste pagina\'s worden dan getoond en de buffer wordt opnieuw opgebouwd.',
'texte_sur_titre' => 'opschrift',
'texte_syndication' => 'Het is mogelijk om van een site automatisch een lijst met
 nieuws, als de website het toelaat, binnen te halen.
 Hiervoor dien je de syndicatie (nieuwsovername) te
 activeren. <blockquote><i>Sommige hostingproviders laten
 dit niet toe; in dat geval kan je geen nieuwsovername
 vanaf je site laten gebeuren.</i></blockquote>',
'texte_table_ok' => ': deze tabel is OK.',
'texte_tables_indexation_vides' => 'De indices van de zoekmachine zijn leeggemaakt.',
'texte_tentative_recuperation' => 'Poging tot herstel.',
'texte_tenter_reparation' => 'Poging tot herstel van de databank',
'texte_test_proxy' => 'Om de proxy te testen kan je hier het adres geven van de website die je wil bereiken.',
'texte_titre_02' => 'Titel :',
'texte_titre_obligatoire' => '<b>Titel</b> [verplicht]',
'texte_travail_article' => '@nom_auteur_modif@ heeft @date_diff@ minuten geleden aan dit artikel gewerkt',
'texte_travail_collaboratif' => 'Als het vaak gebeurt dat meerdere redacteurs
 aan een en hetzelfde artikel werken, kan het systeem
 wel tonen welke artikels er recent &laquo;geopend&raquo; werden
 om te vermijden op hetzelfde moment simultaan
 wijzigingen worden aangebracht.
 Deze optie is standaard wel niet geactiveerd om te
 vermijden dat er teveel waarschuwingsberichten op het
 scherm verschijnen.',
'texte_trop_resultats_auteurs' => 'Teveel resultaten voor "@cherche_auteur@" ; gelieve de zoekopdracht te verfijnen.',
'texte_type_urls' => 'Vous pouvez choisir ci-dessous le mode de calcul de l\'adresse des pages.',
'texte_type_urls_attention' => 'Aandacht zal dit regelen slechts werken als het bestand @htaccess@ juist aan de wortel van de site wordt geplaatst.',
'texte_unpack' => 'binnenhalen van de laatste versie',
'texte_utilisation_moteur_syndiques' => 'Wanneer u de ge&iuml;ntegreerdeb de zoekmotor van
 SPIP, kunt u het onderzoek naar de site en
 instellen    de georganiseerde artikelen op twee wijze
    verschillend. <br />- De meest
 eenvoudige manier bestaat erin om alleen te zoeken in titels en
 beschrijvingen van de artikels. <br />-
 Een andere methode is veel krachtiger en laat
 eveneens toe op de tekst van de gekoppelde sites te zoeken&nbsp;. Als je
 een site hebt gekoppeld, zal SPIP de zoekopdracht
 uitbreiden tot de tekst van deze site zelf.',
'texte_utilisation_moteur_syndiques_2' => 'Deze methode verplicht SPIP om de gekoppelde
 site regelmatig te bezoeken, wat een kleine
 vertraging van je eigen site tot gevolg kan hebben.',
'texte_vide' => 'leeg',
'texte_vider_cache' => 'Cache leegmaken',
'titre_admin_effacer' => 'Technisch onderhoud',
'titre_admin_tech' => 'Technisch onderhoud',
'titre_admin_vider' => 'Technisch onderhoud',
'titre_articles_syndiques' => 'Gesyndiceerde artikels komende van deze site',
'titre_breves' => 'Berichten',
'titre_cadre_afficher_article' => 'Artikels tonen',
'titre_cadre_afficher_traductions' => 'Toon de status van de vertalingen voor de volgende talen&nbsp;:',
'titre_cadre_ajouter_auteur' => 'EEN AUTEUR TOEVOEGEN :',
'titre_cadre_forum_administrateur' => 'Priv&eacute;-forum voor de beheerders',
'titre_cadre_forum_interne' => 'Intern forum',
'titre_cadre_interieur_rubrique' => 'In de rubriek',
'titre_cadre_numero_auteur' => 'AUTEUR NUMMER',
'titre_cadre_signature_obligatoire' => '<b>Handtekening</b> [Verplicht]<br />',
'titre_compacter_script_css' => 'Verdichting van de scripts en CSS',
'titre_compresser_flux_http' => 'Samendrukking van de HTTP stroom',
'titre_config_contenu_notifications' => 'Kennisgevingen',
'titre_config_contenu_prive' => 'In de particuliere ruimte',
'titre_config_contenu_public' => 'Op de openbare site',
'titre_config_fonctions' => 'Configuratie van de site',
'titre_config_forums_prive' => 'Forums van de particuliere ruimte',
'titre_config_groupe_mots_cles' => 'Configuratie van de groepen trefwoorden',
'titre_configuration' => 'Configuratie van de site',
'titre_conflit_edition' => 'Conflict bij de uitgave',
'titre_connexion_ldap' => 'Opties: <b>Je LDAP-verbinding</b>',
'titre_dernier_article_syndique' => 'Meest recente gesyndiceerde artikels',
'titre_documents_joints' => 'Bijlagen',
'titre_evolution_visite' => 'Evolutie van de bezoeken',
'titre_forum_suivi' => 'Vervolg van de forums',
'titre_gauche_mots_edit' => 'WOORD NUMMER:',
'titre_groupe_mots' => 'WOORDENGROEP:',
'titre_langue_article' => 'TAAL VAN HET ATIKEL',
'titre_langue_breve' => 'TAAL VAN HET NIEUWSBERICHT',
'titre_langue_rubrique' => 'TAAL VAN DE RUBRIEK',
'titre_langue_trad_article' => 'TAAL EN VERTALINGEN VAN HET ARTIKEL',
'titre_les_articles' => 'ARTIKELS',
'titre_messagerie_agenda' => 'Besteldienst en agenda',
'titre_mots_cles_dans_forum' => 'Trefwoorden in de forums van de publieke site',
'titre_mots_tous' => 'Trefwoorden',
'titre_naviguer_dans_le_site' => 'Bezoek de site...',
'titre_nouveau_groupe' => 'Nieuwe groep',
'titre_nouvelle_breve' => 'Nieuw bericht',
'titre_nouvelle_rubrique' => 'Nieuwe rubriek',
'titre_numero_rubrique' => 'RUBRIEKNUMMER:',
'titre_page_admin_effacer' => 'Technische onderhoud : de databank wissen',
'titre_page_articles_edit' => 'Wijzigen : @titre@',
'titre_page_articles_page' => 'Artikels',
'titre_page_articles_tous' => 'Volledige site',
'titre_page_auteurs' => 'Bezoekers',
'titre_page_breves' => 'Berichten',
'titre_page_breves_edit' => 'Wijzigen bericht : &laquo;@titre@&raquo;',
'titre_page_calendrier' => 'Kalender @nom_mois@ @annee@',
'titre_page_config_contenu' => 'Websiteconfiguratie',
'titre_page_config_fonctions' => 'Websiteconfiguratie',
'titre_page_configuration' => 'Websiteconfiguratie',
'titre_page_controle_petition' => 'Vervolg van de petities',
'titre_page_delete_all' => 'Volledige en onomkeerbare verwijdering',
'titre_page_documents_liste' => 'Documenten van de rubrieken',
'titre_page_forum' => 'Forum van de beheerders',
'titre_page_forum_envoi' => 'Een bericht versturen',
'titre_page_forum_suivi' => 'Vervolg van de forums',
'titre_page_index' => 'Je priv&eacute;-ruimte',
'titre_page_message_edit' => 'Een bericht opstellen',
'titre_page_messagerie' => 'Je brievenbus',
'titre_page_mots_tous' => 'Trefwoorden',
'titre_page_recherche' => 'Zoekresultaat voor @recherche@ ',
'titre_page_sites_tous' => 'De referentiesites',
'titre_page_statistiques' => 'Statistieken per rubriek',
'titre_page_statistiques_messages_forum' => 'Berichten van forum',
'titre_page_statistiques_referers' => 'Statistieken (per referer)',
'titre_page_statistiques_signatures_jour' => 'Aantal handtekeningen per dag',
'titre_page_statistiques_signatures_mois' => 'Aantal handtekeningen per maand',
'titre_page_statistiques_visites' => 'Statistieken van de bezoeken',
'titre_page_upgrade' => 'Bijwerken van SPIP',
'titre_publication_articles_post_dates' => 'Publicatie van postgedateerde artikels',
'titre_referencement_sites' => 'Koppelen van sites en syndicatie',
'titre_referencer_site' => 'Deze site koppelen :',
'titre_rendez_vous' => 'AFSPRAKEN :',
'titre_reparation' => 'Herstel',
'titre_site_numero' => 'WEBSITE NUMMER:',
'titre_sites_proposes' => 'Voorgestelde sites',
'titre_sites_references_rubrique' => 'Gekoppelde sites in deze rubriek',
'titre_sites_syndiques' => 'Gesyndiceerde sites',
'titre_sites_tous' => 'Gekoppelde sites',
'titre_suivi_petition' => 'Vervolg van de petities',
'titre_syndication' => 'Syndicatie van websites',
'titre_type_urls' => 'Soort adressen URL',
'tls_ldap' => 'Transport Layer Security :',
'tout_dossier_upload' => 'Alles in de map @upload@',
'trad_article_inexistant' => 'Er is geen artikel met dit nummer.',
'trad_article_traduction' => 'Alle versies van dit artikel:',
'trad_deja_traduit' => 'Fout: onmogelijk om dit artikel te verbinden met het gevraagde nummer.',
'trad_delier' => 'Dit artikel niet meer koppelen aan zijn vertalingen',
'trad_lier' => 'Dit artikel is een vertaling van artikelnummer:',
'trad_new' => 'Een nieuwe vertaling maken van dit artikel',

// U
'upload_fichier_zip' => 'ZIP bestand',
'upload_fichier_zip_texte' => 'Het bestand dat je wil installeren is een ZIP bestand.',
'upload_fichier_zip_texte2' => 'Dit bestand kan zijn&nbsp;:',
'upload_info_mode_document' => 'Dit beeld in portfolio neerzetten',
'upload_info_mode_image' => 'Dit beeld van portfolio terugtrekken',
'upload_limit' => 'Dit bestand is te groot voor de server&nbsp;; de maximale bestandsgrootte voor <i>upload</i> is @max@.',
'upload_zip_conserver' => 'Het archief behouden na winning',
'upload_zip_decompacter' => 'uitgepakt en elk bestand ge&iuml;nstalleerd op de site. De bestanden die op de site komen, zijn&nbsp;:',
'upload_zip_telquel' => 'ge&iuml;nstalleerd als gezipt (gecomprimeerd) bestand&nbsp;;',
'upload_zip_titrer' => 'Volgens de naam bestanden betitelen',
'utf8_convert_attendez' => 'Wacht enkele ogenblikken en herlaadt deze pagina.',
'utf8_convert_avertissement' => 'U heeft zich klaargemaakt om de inhoud van uw site (artikels, berichten, enz) om te zetten van karakterset <b>@orig@</b> naar karakterset <b>@charset@</b>.',
'utf8_convert_backup' => 'Vergeet niet om vooraf uw volledige site te bewaren. U dient ook na te gaan of uw sjablonen en taalbestanden @charset@ compatibel zijn.',
'utf8_convert_erreur_deja' => 'Uw site is reeds in @charset@, onnodig om hem om te zetten...',
'utf8_convert_erreur_orig' => 'Fout&nbsp;: de karakterset @charset@ wordt niet ondersteund.',
'utf8_convert_termine' => 'Opdracht volbracht&nbsp;!',
'utf8_convert_timeout' => '<b>Belangrijk&nbsp;:</b> indien de server <i>timeout</i> aangeeft, dien je de pagina te herladen tot ze &laquo;&nbsp;volbracht&nbsp;&raquo; aangeeft.',
'utf8_convert_verifier' => 'Je kan nu de buffer leegmaken en nagaan of alles goed werkt op je publieke site. Als het goed fout gaat, kan je terugvallen op een backup die in SQL formaat in de map @rep@ bewaard werd.',
'utf8_convertir_votre_site' => 'Je site omzetten naar utf-8',

// V
'version' => 'Versie&nbsp;:',
'version_deplace_rubrique' => 'Verplaatsen van <b>&laquo;&nbsp;@from@&nbsp;&raquo;</b> naar <b>&laquo;&nbsp;@to@&nbsp;&raquo;</b>.',
'version_initiale' => 'Beginversie'
);

?>
